@@ -17,17 +17,17 @@
 
 #include "../common/config.hpp"
 #include "aboutdlg.hpp"
+#include "editordata.hpp"
+#include "editorview.hpp"
+#include "mediator.hpp"
+#include "newtrackdialog.hpp"
 #include "object.hpp"
 #include "objectmodel.hpp"
 #include "objectmodelloader.hpp"
-#include "trackio.hpp"
 #include "trackdata.hpp"
+#include "trackio.hpp"
 #include "trackpropertiesdialog.hpp"
 #include "tracktile.hpp"
-#include "editordata.hpp"
-#include "editorview.hpp"
-#include "editorscene.hpp"
-#include "newtrackdialog.hpp"
 
 #include <QAction>
 #include <QApplication>
@@ -36,45 +36,34 @@
 #include <QDesktopWidget>
 #include <QFileDialog>
 #include <QGraphicsLineItem>
+#include <QHBoxLayout>
+#include <QLabel>
 #include <QMenu>
 #include <QMenuBar>
 #include <QMessageBox>
-#include <QLabel>
 #include <QSettings>
 #include <QSlider>
 #include <QSplitter>
 #include <QStandardPaths>
 #include <QTextEdit>
 #include <QTimer>
-#include <QTransform>
 #include <QToolBar>
-#include <QHBoxLayout>
+#include <QTransform>
 #include <QVBoxLayout>
 
 #include <cassert>
 
 MainWindow * MainWindow::m_instance = nullptr;
 
-namespace
-{
-    const char *       SETTINGS_GROUP = "MainWindow";
-    const unsigned int MIN_ZOOM       = 0;
-    const unsigned int MAX_ZOOM       = 200;
-    const unsigned int INI_ZOOM       = 100;
-    const int          CONSOLE_HEIGHT = 64;
-}
-
 MainWindow::MainWindow(QString trackFile)
-: m_objectModelLoader(new ObjectModelLoader)
-, m_aboutDlg(new AboutDlg(this))
-, m_editorData(new EditorData(this))
-, m_editorScene(new EditorScene(this))
-, m_editorView(new EditorView(*m_editorData, this))
-, m_console(new QTextEdit(this))
-, m_scaleSlider(new QSlider(Qt::Horizontal, this))
-, m_toolBar(new QToolBar(this))
-, m_randomRotationCheck(new QCheckBox(tr("Randomly rotate objects"), this))
-, m_argTrackFile(trackFile)
+  : m_objectModelLoader(std::make_unique<ObjectModelLoader>())
+  , m_mediator(std::make_unique<Mediator>(*this))
+  , m_aboutDlg(new AboutDlg(this))
+  , m_console(new QTextEdit(this))
+  , m_scaleSlider(new QSlider(Qt::Horizontal, this))
+  , m_toolBar(new QToolBar(this))
+  , m_randomRotationCheck(new QCheckBox(tr("Randomly rotate objects"), this))
+  , m_argTrackFile(trackFile)
 {
     if (!m_instance)
     {
@@ -92,13 +81,12 @@ MainWindow::MainWindow(QString trackFile)
     console("CWD: " + QDir::currentPath());
 
     // Load object models that can be used to build tracks.
-    const QString objectFilePath = QString(Config::Common::dataPath) +
-        QDir::separator() + QString(Config::Editor::MODEL_CONFIG_FILE_NAME);
+    const QString objectFilePath = QString(Config::General::dataPath) + QDir::separator() + QString(Config::Editor::MODEL_CONFIG_FILE_NAME);
     loadObjectModels(objectFilePath);
 
     if (!m_argTrackFile.isEmpty())
     {
-        QTimer::singleShot(0, this, SLOT(openArgTrack()));
+        QTimer::singleShot(0, this, &MainWindow::openArgTrack);
     }
     else
     {
@@ -122,13 +110,32 @@ void MainWindow::setVisible(bool visible)
     }
 }
 
+void MainWindow::updateScaleSlider(int value)
+{
+    m_scaleSlider->setValue(value);
+}
+
 void MainWindow::showTip()
 {
+    const auto commonTitle = tr("Save your work to correct location.");
+#ifdef __unix__
     QMessageBox::information(
-        this,
-        tr("Save your work to correct location."),
-        QString(tr("To make the game find your circuits, save them to %1%2%3%2"))
-            .arg(QDir::homePath()).arg(QDir::separator()).arg(Config::Common::TRACK_SEARCH_PATH));
+      this,
+      commonTitle,
+      QString(tr("To make the game find your circuits, save them to %1%2%3%2") + tr(", %4%2"))
+        .arg(QDir::homePath())
+        .arg(QDir::separator())
+        .arg(Config::General::TRACK_SEARCH_PATH)
+        .arg(Config::General::Unix::getXdgTrackSearchPath()));
+#else
+    QMessageBox::information(
+      this,
+      commonTitle,
+      QString(tr("To make the game find your circuits, save them to %1%2%3%2"))
+        .arg(QDir::homePath())
+        .arg(QDir::separator())
+        .arg(Config::General::TRACK_SEARCH_PATH));
+#endif
 }
 
 void MainWindow::init()
@@ -138,24 +145,24 @@ void MainWindow::init()
     QSettings settings;
 
     // Read dialog size data
-    settings.beginGroup(SETTINGS_GROUP);
+    settings.beginGroup(m_settingsGroup);
     resize(settings.value("size", QSize(640, 480)).toSize());
     settings.endGroup();
 
     // Try to center the window.
     QRect geometry(QApplication::desktop()->availableGeometry());
     move(geometry.width() / 2 - width() / 2,
-        geometry.height() / 2 - height() / 2);
+         geometry.height() / 2 - height() / 2);
+
+    m_mediator->initScene();
 
-    // Populate menu bar with actions
     populateMenuBar();
 
-    // Set scene to the view
-    m_editorView->setScene(m_editorScene);
-    m_editorView->setSizePolicy(QSizePolicy::Preferred,
-        QSizePolicy::Expanding);
-    m_editorView->setMouseTracking(true);
+    createWidgets();
+}
 
+void MainWindow::createWidgets()
+{
     // Create a splitter
     QSplitter * splitter = new QSplitter(this);
     splitter->setOrientation(Qt::Vertical);
@@ -164,7 +171,7 @@ void MainWindow::init()
     QVBoxLayout * centralLayout = new QVBoxLayout;
     QHBoxLayout * viewToolBarLayout = new QHBoxLayout;
     m_toolBar->setOrientation(Qt::Vertical);
-    viewToolBarLayout->addWidget(m_editorView);
+    m_mediator->addViewToLayout(viewToolBarLayout);
     viewToolBarLayout->addWidget(m_toolBar);
     centralLayout->addLayout(viewToolBarLayout);
 
@@ -172,12 +179,12 @@ void MainWindow::init()
     populateToolBar();
 
     // Add zoom slider to the layout
-    m_scaleSlider->setRange(MIN_ZOOM, MAX_ZOOM);
-    m_scaleSlider->setValue(INI_ZOOM);
+    m_scaleSlider->setRange(m_minZoom, m_maxZoom);
+    m_scaleSlider->setValue(m_initZoom);
     m_scaleSlider->setTracking(false);
     m_scaleSlider->setTickInterval(10);
     m_scaleSlider->setTickPosition(QSlider::TicksBelow);
-    connect(m_scaleSlider, SIGNAL(valueChanged(int)), this, SLOT(updateScale(int)));
+    connect(m_scaleSlider, &QSlider::valueChanged, this, &MainWindow::updateScale);
     QHBoxLayout * sliderLayout = new QHBoxLayout;
     sliderLayout->addWidget(new QLabel(tr("Scale:")));
     sliderLayout->addWidget(m_scaleSlider);
@@ -207,15 +214,14 @@ void MainWindow::init()
     setCentralWidget(splitter);
 
     QList<int> sizes;
-    sizes << height() - CONSOLE_HEIGHT << CONSOLE_HEIGHT;
+    sizes << height() - m_consoleHeight << m_consoleHeight;
     splitter->setSizes(sizes);
 }
 
 void MainWindow::setTitle(QString openFileName)
 {
     setWindowTitle(
-        QString(Config::Editor::EDITOR_NAME) + " " + Config::Editor::EDITOR_VERSION + " - " +
-        openFileName);
+      QString(Config::Editor::EDITOR_NAME) + " " + Config::Editor::EDITOR_VERSION + " - " + openFileName);
 }
 
 bool MainWindow::randomlyRotateObjects() const
@@ -232,8 +238,7 @@ bool MainWindow::loadObjectModels(QString objectFilePath)
     }
     else
     {
-        const QString msg = tr("ERROR!!: Cannot load objects from '") +
-            objectFilePath + tr("'");
+        const QString msg = tr("ERROR!!: Cannot load objects from '") + objectFilePath + tr("'");
         console(msg);
         return false;
     }
@@ -244,15 +249,16 @@ void MainWindow::addObjectsToToolBar()
     // Loop through all object models loaded
     // by the object loader.
     QVector<QString> categories;
-    categories << "tile" << "free";
+    categories << "tile"
+               << "free";
     for (QString category : categories)
     {
         ObjectModelLoader::ObjectDataVector objects =
-            m_objectModelLoader->getObjectModelsByCategory(category);
-        for (const ObjectModel model : objects)
+          m_objectModelLoader->getObjectModelsByCategory(category);
+        for (const ObjectModel & model : objects)
         {
             // Create the action.
-            QAction * p = new QAction(QIcon(model.pixmap), model.role, this);
+            auto p = new QAction(QIcon(model.pixmap), model.role, this);
 
             // Set model role as the data.
             p->setData(QVariant(model.role));
@@ -268,21 +274,6 @@ MainWindow * MainWindow::instance()
     return MainWindow::m_instance;
 }
 
-EditorView & MainWindow::editorView() const
-{
-    return *m_editorView;
-}
-
-EditorScene & MainWindow::editorScene() const
-{
-    return *m_editorScene;
-}
-
-EditorData & MainWindow::editorData() const
-{
-    return *m_editorData;
-}
-
 ObjectModelLoader & MainWindow::objectModelLoader() const
 {
     return *m_objectModelLoader;
@@ -295,11 +286,7 @@ QAction * MainWindow::currentToolBarAction() const
 
 void MainWindow::updateScale(int value)
 {
-    qreal scale = static_cast<qreal>(value) / 100;
-
-    QTransform transform;
-    transform.scale(scale, scale);
-    m_editorView->setTransform(transform);
+    m_mediator->setScale(value);
 
     console(QString(tr("Scale set to %1%")).arg(value));
 }
@@ -310,7 +297,7 @@ void MainWindow::closeEvent(QCloseEvent * event)
     QSettings settings;
 
     // Save window size
-    settings.beginGroup(SETTINGS_GROUP);
+    settings.beginGroup(m_settingsGroup);
     settings.setValue("size", size());
     settings.endGroup();
 
@@ -326,33 +313,33 @@ void MainWindow::populateMenuBar()
     QAction * newAct = new QAction(tr("&New..."), this);
     newAct->setShortcut(QKeySequence("Ctrl+N"));
     fileMenu->addAction(newAct);
-    connect(newAct, SIGNAL(triggered()), this, SLOT(initializeNewTrack()));
+    connect(newAct, &QAction::triggered, this, &MainWindow::initializeNewTrack);
 
     // Add "open"-action
     QAction * openAct = new QAction(tr("&Open..."), this);
     openAct->setShortcut(QKeySequence("Ctrl+O"));
     fileMenu->addAction(openAct);
-    connect(openAct, SIGNAL(triggered()), this, SLOT(openTrack()));
+    connect(openAct, &QAction::triggered, this, &MainWindow::openTrack);
 
     // Add "save"-action
     m_saveAction = new QAction(tr("&Save"), this);
     m_saveAction->setShortcut(QKeySequence("Ctrl+S"));
     fileMenu->addAction(m_saveAction);
-    connect(m_saveAction, SIGNAL(triggered()), this, SLOT(saveTrack()));
+    connect(m_saveAction, &QAction::triggered, this, &MainWindow::saveTrack);
     m_saveAction->setEnabled(false);
 
     // Add "save as"-action
     m_saveAsAction = new QAction(tr("&Save as..."), this);
     m_saveAsAction->setShortcut(QKeySequence("Ctrl+Shift+S"));
     fileMenu->addAction(m_saveAsAction);
-    connect(m_saveAsAction, SIGNAL(triggered()), this, SLOT(saveAsTrack()));
+    connect(m_saveAsAction, &QAction::triggered, this, &MainWindow::saveAsTrack);
     m_saveAsAction->setEnabled(false);
 
     // Add "quit"-action
     QAction * quitAct = new QAction(tr("&Quit"), this);
     quitAct->setShortcut(QKeySequence("Ctrl+W"));
     fileMenu->addAction(quitAct);
-    connect(quitAct, SIGNAL(triggered()), this, SLOT(close()));
+    connect(quitAct, &QAction::triggered, this, &MainWindow::close);
 
     // Create "edit"-menu
     QMenu * editMenu = menuBar()->addMenu(tr("&Edit"));
@@ -361,13 +348,13 @@ void MainWindow::populateMenuBar()
     m_undoAction = new QAction(tr("Undo"), this);
     m_undoAction->setShortcut(QKeySequence("Ctrl+Z"));
     editMenu->addAction(m_undoAction);
-    connect(m_undoAction, &QAction::triggered, [this](){
-        m_editorData->undo();
+    connect(m_undoAction, &QAction::triggered, [this]() {
+        m_mediator->undo();
 
         setupTrackAfterUndoOrRedo();
 
-        m_undoAction->setEnabled(m_editorData->isUndoable());
-        m_redoAction->setEnabled(m_editorData->isRedoable());
+        m_undoAction->setEnabled(m_mediator->isUndoable());
+        m_redoAction->setEnabled(m_mediator->isRedoable());
     });
     m_undoAction->setEnabled(false);
 
@@ -375,32 +362,20 @@ void MainWindow::populateMenuBar()
     m_redoAction = new QAction(tr("Redo"), this);
     m_redoAction->setShortcut(QKeySequence("Ctrl+Shift+Z"));
     editMenu->addAction(m_redoAction);
-    connect(m_redoAction, &QAction::triggered, [this](){
-        m_editorData->redo();
+    connect(m_redoAction, &QAction::triggered, [this]() {
+        m_mediator->redo();
 
         setupTrackAfterUndoOrRedo();
 
-        m_undoAction->setEnabled(m_editorData->isUndoable());
-        m_redoAction->setEnabled(m_editorData->isRedoable());
+        m_undoAction->setEnabled(m_mediator->isUndoable());
+        m_redoAction->setEnabled(m_mediator->isRedoable());
     });
     m_redoAction->setEnabled(false);
 
-    // Add "enlarge hor size"-action
-    m_enlargeHorSize = new QAction(tr("Enlarge hor size"), this);
-    editMenu->addAction(m_enlargeHorSize);
-    connect(m_enlargeHorSize, SIGNAL(triggered()), this, SLOT(enlargeHorSize()));
-    m_enlargeHorSize->setEnabled(false);
-
-    // Add "enlarge ver size"-action
-    m_enlargeVerSize = new QAction(tr("Enlarge ver size"), this);
-    editMenu->addAction(m_enlargeVerSize);
-    connect(m_enlargeVerSize, SIGNAL(triggered()), this, SLOT(enlargeVerSize()));
-    m_enlargeVerSize->setEnabled(false);
-
     // Add "Set track properties"-action
     m_setTrackPropertiesAction = new QAction(tr("&Set properties.."), this);
     editMenu->addAction(m_setTrackPropertiesAction);
-    connect(m_setTrackPropertiesAction, SIGNAL(triggered()), this, SLOT(setTrackProperties()));
+    connect(m_setTrackPropertiesAction, &QAction::triggered, this, &MainWindow::setTrackProperties);
     m_setTrackPropertiesAction->setEnabled(false);
 
     // Create "route"-menu
@@ -409,13 +384,13 @@ void MainWindow::populateMenuBar()
     // Add "clear"-action
     m_clearRouteAction = new QAction(tr("Clear &route"), this);
     routeMenu->addAction(m_clearRouteAction);
-    connect(m_clearRouteAction, SIGNAL(triggered()), this, SLOT(clearRoute()));
+    connect(m_clearRouteAction, &QAction::triggered, this, &MainWindow::clearRoute);
     m_clearRouteAction->setEnabled(false);
 
     // Add "set order"-action
     m_setRouteAction = new QAction(tr("&Set route.."), this);
     routeMenu->addAction(m_setRouteAction);
-    connect(m_setRouteAction, SIGNAL(triggered()), this, SLOT(beginSetRoute()));
+    connect(m_setRouteAction, &QAction::triggered, this, &MainWindow::beginSetRoute);
     m_setRouteAction->setEnabled(false);
 
     // Create "help"-menu
@@ -424,12 +399,12 @@ void MainWindow::populateMenuBar()
     // Add "about"-action
     QAction * aboutAct = new QAction(tr("&About"), this);
     helpMenu->addAction(aboutAct);
-    connect(aboutAct, SIGNAL(triggered()), this, SLOT(showAboutDlg()));
+    connect(aboutAct, &QAction::triggered, this, &MainWindow::showAboutDlg);
 
     // Add "about Qt"-action
     QAction * aboutQtAct = new QAction(tr("About &Qt"), this);
     helpMenu->addAction(aboutQtAct);
-    connect(aboutQtAct, SIGNAL(triggered()), this, SLOT(showAboutQtDlg()));
+    connect(aboutQtAct, &QAction::triggered, this, &MainWindow::showAboutQtDlg);
 }
 
 void MainWindow::populateToolBar()
@@ -441,7 +416,7 @@ void MainWindow::populateToolBar()
 
     // Add "erase"-action
     p = new QAction(
-        QIcon(QPixmap(Config::Editor::ERASE_ICON_PATH)), tr("Erase object"), this);
+      QIcon(QPixmap(Config::Editor::ERASE_ICON_PATH)), tr("Erase object"), this);
     p->setData(QVariant(QString("erase")));
     m_toolBar->addAction(p);
 
@@ -450,8 +425,7 @@ void MainWindow::populateToolBar()
     p->setData(QVariant(QString("clear")));
     m_toolBar->addAction(p);
 
-    connect(m_toolBar, SIGNAL(actionTriggered(QAction*)),
-        this, SLOT(handleToolBarActionClick(QAction*)));
+    connect(m_toolBar, &QToolBar::actionTriggered, this, &MainWindow::handleToolBarActionClick);
 
     m_toolBar->setEnabled(false);
 }
@@ -460,8 +434,6 @@ void MainWindow::handleToolBarActionClick(QAction * action)
 {
     if (action != m_currentToolBarAction)
     {
-        assert(m_editorData);
-
         m_currentToolBarAction = action;
 
         // Select-action
@@ -474,30 +446,32 @@ void MainWindow::handleToolBarActionClick(QAction * action)
         {
             QApplication::restoreOverrideCursor();
             QApplication::setOverrideCursor(QCursor(action->icon().pixmap(32, 32)));
-            m_editorData->setMode(EditorData::EditorMode::EraseObject);
+            m_mediator->setMode(EditorMode::EraseObject);
         }
         // The user wants to clear a tile.
         else if (action->data() == "clear")
         {
             QApplication::restoreOverrideCursor();
             QApplication::setOverrideCursor(QCursor(action->icon().pixmap(32, 32)));
-            m_editorData->setMode(EditorData::EditorMode::SetTileType);
+            m_mediator->setMode(EditorMode::SetTileType);
         }
         // The user wants to set a tile type or clear it.
         else if (m_objectModelLoader->getCategoryByRole(
-            action->data().toString()) == "tile")
+                   action->data().toString())
+                 == "tile")
         {
             QApplication::restoreOverrideCursor();
             QApplication::setOverrideCursor(QCursor(action->icon().pixmap(32, 32)));
-            m_editorData->setMode(EditorData::EditorMode::SetTileType);
+            m_mediator->setMode(EditorMode::SetTileType);
         }
         // The user wants to add an object to the scene.
         else if (m_objectModelLoader->getCategoryByRole(
-            action->data().toString()) == "free")
+                   action->data().toString())
+                 == "free")
         {
             QApplication::restoreOverrideCursor();
             QApplication::setOverrideCursor(QCursor(QPixmap(":/cursor2.png")));
-            m_editorData->setMode(EditorData::EditorMode::AddObject);
+            m_mediator->setMode(EditorMode::AddObject);
         }
     }
     else
@@ -514,13 +488,14 @@ void MainWindow::openTrack()
     // Load recent path
     QSettings settings;
 
-    settings.beginGroup(SETTINGS_GROUP);
+    settings.beginGroup(m_settingsGroup);
     QString path = settings.value("recentPath",
-    QStandardPaths::writableLocation(QStandardPaths::HomeLocation)).toString();
+                                  QStandardPaths::writableLocation(QStandardPaths::HomeLocation))
+                     .toString();
     settings.endGroup();
 
     const QString fileName = QFileDialog::getOpenFileName(
-        this, tr("Open a track"), path, tr("Track Files (*.trk)"));
+      this, tr("Open a track"), path, tr("Track Files (*.trk)"));
     if (!fileName.isEmpty())
     {
         doOpenTrack(fileName);
@@ -539,9 +514,8 @@ void MainWindow::showAboutQtDlg()
 
 void MainWindow::clearRoute()
 {
-    assert(m_editorData);
-    m_editorData->saveUndoPoint();
-    m_editorData->clearRoute();
+    m_mediator->clearRoute();
+
     m_clearRouteAction->setEnabled(false);
 }
 
@@ -553,13 +527,11 @@ bool MainWindow::doOpenTrack(QString fileName)
         return false;
     }
 
-    assert(m_editorData);
-
     // Undo stack will be cleared.
     m_undoAction->setEnabled(false);
     m_redoAction->setEnabled(false);
 
-    if (m_editorData->loadTrackData(fileName))
+    if (m_mediator->openTrack(fileName))
     {
         console(QString(tr("Track '%1' opened.").arg(fileName)));
 
@@ -568,7 +540,7 @@ bool MainWindow::doOpenTrack(QString fileName)
         // Save recent path
         QSettings settings;
 
-        settings.beginGroup(SETTINGS_GROUP);
+        settings.beginGroup(m_settingsGroup);
         settings.setValue("recentPath", fileName);
         settings.endGroup();
 
@@ -576,50 +548,99 @@ bool MainWindow::doOpenTrack(QString fileName)
 
         setActionStatesOnNewTrack();
 
-        delete m_editorScene;
-        m_editorScene = new EditorScene;
-
-        m_editorView->setScene(m_editorScene);
-        m_editorView->updateSceneRect();
-
-        m_editorData->addTilesToScene();
-        m_editorData->addObjectsToScene();
-        m_editorData->addExistingRouteToScene();
-
         fitScale();
 
         m_saved = true;
 
-        m_clearRouteAction->setEnabled(m_editorData->trackData()->route().numNodes());
+        m_clearRouteAction->setEnabled(m_mediator->routeHasNodes());
 
         return true;
     }
-    else
-    {
-        console(QString(tr("Failed to open track '")) + fileName + "'.");
-        return false;
-    }
 
+    console(QString(tr("Failed to open track '")) + fileName + "'.");
     return false;
 }
 
-void MainWindow::setupTrackAfterUndoOrRedo()
+void MainWindow::beginSetRoute()
 {
-    m_saveAction->setEnabled(true);
+    if (m_mediator->beginSetRoute())
+    {
+        console(tr("Set route: begin."));
+        QMessageBox::information(
+          this,
+          tr("Set route, checkpoints and driving lines."),
+          tr("Setting the route defines checkpoints for the cars so\n"
+             "that no shortcuts can be taken. It also defines\n"
+             "driving lines for the computer players.\n\n"
+             "Click on the tiles one by one and make a closed loop\n"
+             "with the target nodes. You can adjust the nodes afterwads.\n"
+             "Start from the first tile after the finish line tile\n"
+             "to make the lap detection and timing work correctly.\n"
+             "Click on the first node again to finish."));
+    }
+    else
+    {
+        console(tr("Set route: not a valid track."));
+        QMessageBox::critical(this, tr("Set route"), tr("Invalid track. Route cannot be set."));
+    }
+}
 
-    setActionStatesOnNewTrack();
+void MainWindow::clearEditMode()
+{
+    m_mediator->clearEditMode();
+}
 
-    delete m_editorScene;
-    m_editorScene = new EditorScene;
+void MainWindow::console(QString text)
+{
+    QDateTime date = QDateTime::currentDateTime();
+    m_console->append(QString("(") + date.toString("hh:mm:ss") + "): " + text);
+}
 
-    m_editorView->setScene(m_editorScene);
-    m_editorView->updateSceneRect();
+void MainWindow::enableUndo(bool enable)
+{
+    m_undoAction->setEnabled(enable);
+}
 
-    m_editorData->addTilesToScene();
-    m_editorData->addObjectsToScene();
-    m_editorData->addExistingRouteToScene();
+void MainWindow::endSetRoute()
+{
+    m_mediator->endSetRoute();
 
-    m_clearRouteAction->setEnabled(m_editorData->trackData()->route().numNodes());
+    m_clearRouteAction->setEnabled(m_mediator->routeHasNodes());
+
+    console(tr("Set route: route finished."));
+}
+
+void MainWindow::fitScale()
+{
+    m_scaleSlider->setValue(m_mediator->fitScale());
+}
+
+void MainWindow::initializeNewTrack()
+{
+    const auto trackData = m_mediator->initializeNewTrack();
+    if (std::get<bool>(trackData))
+    {
+        // Undo stack has been cleared.
+        m_undoAction->setEnabled(false);
+        m_redoAction->setEnabled(false);
+
+        fitScale();
+
+        setActionStatesOnNewTrack();
+
+        setTitle(tr("New file"));
+
+        m_clearRouteAction->setEnabled(false);
+
+        m_saved = false;
+
+        console(QString(tr("A new track '%1' created. Columns: %2, Rows: %3."))
+                  .arg(std::get<1>(trackData))
+                  .arg(std::get<2>(trackData))
+                  .arg(std::get<3>(trackData)));
+    }
+
+    QApplication::restoreOverrideCursor();
 }
 
 void MainWindow::saveTrack()
@@ -632,18 +653,15 @@ void MainWindow::saveTrack()
     }
     else
     {
-        assert(m_editorData);
-        if (m_editorData->saveTrackData())
+        if (m_mediator->saveTrackData())
         {
-            console(QString(
-                tr("Track '")) + m_editorData->trackData()->fileName() + tr("' saved."));
-            setTitle(m_editorData->trackData()->fileName());
+            console(QString(tr("Track '")) + m_mediator->currentFileName() + tr("' saved."));
+            setTitle(m_mediator->currentFileName());
             m_saved = true;
         }
         else
         {
-            console(QString(
-                tr("Failed to save track '")) + m_editorData->trackData()->fileName() + "'.");
+            console(QString(tr("Failed to save track '")) + m_mediator->currentFileName() + "'.");
         }
     }
 
@@ -655,9 +673,9 @@ void MainWindow::saveAsTrack()
     QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
 
     QString fileName = QFileDialog::getSaveFileName(this,
-        tr("Save a track"),
-        QStandardPaths::writableLocation(QStandardPaths::HomeLocation),
-        tr("Track Files (*.trk)"));
+                                                    tr("Save a track"),
+                                                    QStandardPaths::writableLocation(QStandardPaths::HomeLocation),
+                                                    tr("Track Files (*.trk)"));
 
     const QString trackFileExtension(".trk");
     if (!fileName.endsWith(trackFileExtension))
@@ -665,8 +683,7 @@ void MainWindow::saveAsTrack()
         fileName += trackFileExtension;
     }
 
-    assert(m_editorData);
-    if (m_editorData->saveTrackDataAs(fileName))
+    if (m_mediator->saveTrackDataAs(fileName))
     {
         console(QString(tr("Track '")) + fileName + tr("' saved."));
         setTitle(fileName);
@@ -680,51 +697,15 @@ void MainWindow::saveAsTrack()
     QApplication::restoreOverrideCursor();
 }
 
-void MainWindow::initializeNewTrack()
+void MainWindow::setupTrackAfterUndoOrRedo()
 {
-    QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+    m_saveAction->setEnabled(true);
 
-    // Show a dialog asking some questions about the track
-    NewTrackDialog dialog(this);
-    if (dialog.exec() == QDialog::Accepted)
-    {
-        const unsigned int cols = dialog.cols();
-        const unsigned int rows = dialog.rows();
+    setActionStatesOnNewTrack();
 
-        assert(m_editorData);
+    m_mediator->setupTrackAfterUndoOrRedo();
 
-        m_editorData->setTrackData(TrackDataPtr(new TrackData(dialog.name(), dialog.isUserTrack(), cols, rows)));
-
-        delete m_editorScene;
-        m_editorScene = new EditorScene;
-
-        m_editorView->setScene(m_editorScene);
-        m_editorView->updateSceneRect();
-
-        // Undo stack has been cleared.
-        m_undoAction->setEnabled(false);
-        m_redoAction->setEnabled(false);
-
-        m_editorData->addTilesToScene();
-        m_editorData->addObjectsToScene();
-
-        fitScale();
-
-        setActionStatesOnNewTrack();
-
-        console(QString(tr("A new track '%1' created. Columns: %2, Rows: %3."))
-            .arg(m_editorData->trackData()->name())
-            .arg(m_editorData->trackData()->map().cols())
-            .arg(m_editorData->trackData()->map().rows()));
-
-        setTitle(tr("New file"));
-
-        m_clearRouteAction->setEnabled(false);
-
-        m_saved = false;
-    }
-
-    QApplication::restoreOverrideCursor();
+    m_clearRouteAction->setEnabled(m_mediator->routeHasNodes());
 }
 
 void MainWindow::setActionStatesOnNewTrack()
@@ -732,114 +713,16 @@ void MainWindow::setActionStatesOnNewTrack()
     m_saveAction->setEnabled(true);
     m_saveAsAction->setEnabled(true);
     m_toolBar->setEnabled(true);
-    m_enlargeHorSize->setEnabled(true);
-    m_enlargeVerSize->setEnabled(true);
     m_setRouteAction->setEnabled(true);
     m_setTrackPropertiesAction->setEnabled(true);
 }
 
 void MainWindow::setTrackProperties()
 {
-    // Show a dialog to set some properties e.g. lap count.
-    assert(m_editorData);
-    TrackPropertiesDialog dialog(m_editorData->trackData()->name(), m_editorData->trackData()->index(), m_editorData->trackData()->isUserTrack(), this);
-    if (dialog.exec() == QDialog::Accepted)
+    if (m_mediator->setTrackProperties())
     {
-        m_editorData->trackData()->setName(dialog.name());
-        m_editorData->trackData()->setIndex(dialog.index());
-        m_editorData->trackData()->setUserTrack(dialog.isUserTrack());
         console(QString(tr("Track properties updated.")));
     }
 }
 
-void MainWindow::enlargeHorSize()
-{
-    assert(m_editorData);
-    if (m_editorData->trackData())
-    {
-        m_editorData->trackData()->enlargeHorSize();
-        m_editorData->addTilesToScene();
-
-        m_editorView->updateSceneRect();
-    }
-}
-
-void MainWindow::enlargeVerSize()
-{
-    assert(m_editorData);
-    if (m_editorData->trackData())
-    {
-        m_editorData->trackData()->enlargeVerSize();
-        m_editorData->addTilesToScene();
-
-        m_editorView->updateSceneRect();
-    }
-}
-
-void MainWindow::enableUndo(bool enable)
-{
-    m_undoAction->setEnabled(enable);
-}
-
-void MainWindow::beginSetRoute()
-{
-    QApplication::restoreOverrideCursor();
-
-    assert(m_editorData);
-
-    m_editorData->saveUndoPoint();
-
-    if (m_editorData->canRouteBeSet())
-    {
-        console(tr("Set route: begin."));
-        QMessageBox::information(
-            this,
-            tr("Set route, checkpoints and driving lines."),
-            tr("Setting the route defines checkpoints for the cars so\n"
-               "that no shortcuts can be taken. It also defines\n"
-               "driving lines for the computer players.\n\n"
-               "Click on the tiles one by one and make a closed loop\n"
-               "with the target nodes. You can adjust the nodes afterwads.\n"
-               "Start from the first tile after the finish line tile\n"
-               "to make the lap detection and timing work correctly.\n"
-               "Click on the first node again to finish."));
-        m_editorData->beginSetRoute();
-    }
-    else
-    {
-        QMessageBox::critical(this, tr("Set route"), tr("Invalid track. Route cannot be set."));
-        console(tr("Set route: not a valid track."));
-    }
-}
-
-void MainWindow::endSetRoute()
-{
-    assert(m_editorData);
-    m_editorData->endSetRoute();
-    m_clearRouteAction->setEnabled(m_editorData->trackData()->route().numNodes());
-    console(tr("Set route: route finished."));
-}
-
-void MainWindow::console(QString text)
-{
-    QDateTime date = QDateTime::currentDateTime();
-    m_console->append(QString("(") + date.toString("hh:mm:ss") + "): " + text);
-}
-
-void MainWindow::clearEditMode()
-{
-    QApplication::restoreOverrideCursor();
-    m_editorData->setMode(EditorData::EditorMode::None);
-}
-
-void MainWindow::fitScale()
-{
-    m_editorView->centerOn(m_editorView->sceneRect().center());
-    m_scaleSlider->setValue(m_editorView->viewport()->height() * 100 / m_editorView->sceneRect().height());
-}
-
-MainWindow::~MainWindow()
-{
-    delete m_editorData;
-    delete m_objectModelLoader;
-}
+MainWindow::~MainWindow() = default;
