@@ -12,98 +12,104 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="76"/>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Randomly rotate objects</source>
         <translation>Pyöritä objekteja satunnaisesti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="111"/>
+        <location filename="../mainwindow.cpp" line="99"/>
         <source>Loading &apos;%1&apos;..</source>
         <translation>Ladataan &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="93"/>
         <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
         <translation>Valitse &apos;Tiedosto -&gt; Uusi&apos; tai &apos;Tiedosto -&gt; Avaa&apos; aloittaaksesi.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="129"/>
+        <location filename="../mainwindow.cpp" line="120"/>
         <source>Save your work to correct location.</source>
         <translation>Tallenna työsi oikeaan hakemistoon.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../mainwindow.cpp" line="134"/>
         <source>To make the game find your circuits, save them to %1%2%3%2</source>
         <translation>Jotta peli löytäisi ratasi, tallenna ne hakemistoon %1%2%3%2 </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="136"/>
-        <location filename="../mainwindow.cpp" line="720"/>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <source>, %4%2</source>
+        <translation> tai %4%2</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="143"/>
+        <location filename="../mainwindow.cpp" line="636"/>
         <source>New file</source>
         <translation>Uusi tiedosto</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="182"/>
+        <location filename="../mainwindow.cpp" line="189"/>
         <source>Scale:</source>
         <translation>Skaala:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="235"/>
+        <location filename="../mainwindow.cpp" line="241"/>
         <source>ERROR!!: Cannot load objects from &apos;</source>
         <translation>VIRHE!! Ei voida ladata objekteja tiedostosta &apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="236"/>
+        <location filename="../mainwindow.cpp" line="241"/>
         <source>&apos;</source>
         <translation>&apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="304"/>
+        <location filename="../mainwindow.cpp" line="291"/>
         <source>Scale set to %1%</source>
         <translation>Skaala asetettu arvoon %1%</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
+        <location filename="../mainwindow.cpp" line="310"/>
         <source>&amp;File</source>
         <translation>&amp;Tiedosto</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="326"/>
+        <location filename="../mainwindow.cpp" line="313"/>
         <source>&amp;New...</source>
         <translation>&amp;Uusi...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="332"/>
+        <location filename="../mainwindow.cpp" line="319"/>
         <source>&amp;Open...</source>
         <translation>&amp;Avaa...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="338"/>
+        <location filename="../mainwindow.cpp" line="325"/>
         <source>&amp;Save</source>
         <translation>&amp;Tallenna</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="332"/>
         <source>&amp;Save as...</source>
         <translation>Tallenna &amp;nimellä...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="352"/>
+        <location filename="../mainwindow.cpp" line="339"/>
         <source>&amp;Quit</source>
         <translation>&amp;Poistu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="358"/>
+        <location filename="../mainwindow.cpp" line="345"/>
         <source>&amp;Edit</source>
         <translation>&amp;Muokkaa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="348"/>
         <source>Undo</source>
         <translation>Peruuta</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>Redo</source>
         <translation>Tee uudelleen</translation>
     </message>
@@ -112,130 +118,128 @@
         <translation type="vanished">&amp;Tyhjennä kaikki</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
         <source>Enlarge hor size</source>
-        <translation>Suurenna vaakasuunnassa</translation>
+        <translation type="vanished">Suurenna vaakasuunnassa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="395"/>
         <source>Enlarge ver size</source>
-        <translation>Suurenna pystysuunnassa</translation>
+        <translation type="vanished">Suurenna pystysuunnassa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="401"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>&amp;Set properties..</source>
         <translation>&amp;Aseta radan ominaisuuksia...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="407"/>
+        <location filename="../mainwindow.cpp" line="382"/>
         <source>&amp;Route</source>
         <translation>&amp;Reitti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="410"/>
+        <location filename="../mainwindow.cpp" line="385"/>
         <source>Clear &amp;route</source>
         <translation>Tyhjennä &amp;reitti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="391"/>
         <source>&amp;Set route..</source>
         <translation>&amp;Aseta reitti...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="422"/>
+        <location filename="../mainwindow.cpp" line="397"/>
         <source>&amp;Help</source>
         <translation>&amp;Apua</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="400"/>
         <source>&amp;About</source>
         <translation>&amp;Tietoa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="430"/>
+        <location filename="../mainwindow.cpp" line="405"/>
         <source>About &amp;Qt</source>
         <translation>&amp;Tietoa &amp;Qt:sta</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="438"/>
+        <location filename="../mainwindow.cpp" line="413"/>
         <source>Select</source>
         <translation>Valitse</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../mainwindow.cpp" line="419"/>
         <source>Erase object</source>
         <translation>Poista objekti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="449"/>
+        <location filename="../mainwindow.cpp" line="424"/>
         <source>Clear</source>
         <translation>Tyhjennä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
+        <location filename="../mainwindow.cpp" line="498"/>
         <source>Open a track</source>
         <translation>Avaa rata</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
-        <location filename="../mainwindow.cpp" line="660"/>
+        <location filename="../mainwindow.cpp" line="498"/>
+        <location filename="../mainwindow.cpp" line="683"/>
         <source>Track Files (*.trk)</source>
         <translation>Ratatiedostot (*.trk)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="537"/>
+        <location filename="../mainwindow.cpp" line="512"/>
         <source>About Qt</source>
         <translation>Tietoa Qt:sta</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="552"/>
+        <location filename="../mainwindow.cpp" line="526"/>
         <source>ERROR!!: %1 doesn&apos;t exist.</source>
         <translation>VIRHE!!: %1 ei ole olemassa.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="564"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source>Track &apos;%1&apos; opened.</source>
         <translation>Rata &apos;%1&apos; avattu.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="599"/>
+        <location filename="../mainwindow.cpp" line="561"/>
         <source>Failed to open track &apos;</source>
         <translation>Virhe avattaessa rataa &apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
-        <location filename="../mainwindow.cpp" line="671"/>
+        <location filename="../mainwindow.cpp" line="663"/>
+        <location filename="../mainwindow.cpp" line="693"/>
         <source>Track &apos;</source>
         <translation>Rata &apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
-        <location filename="../mainwindow.cpp" line="671"/>
+        <location filename="../mainwindow.cpp" line="663"/>
+        <location filename="../mainwindow.cpp" line="693"/>
         <source>&apos; saved.</source>
         <translation>&apos; tallennettu.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="646"/>
+        <location filename="../mainwindow.cpp" line="669"/>
         <source>Failed to save track &apos;</source>
         <translation>Virhe tallennettaessa rataa &apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="658"/>
+        <location filename="../mainwindow.cpp" line="681"/>
         <source>Save a track</source>
         <translation>Tallenna rata</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="677"/>
+        <location filename="../mainwindow.cpp" line="699"/>
         <source>Failed to save track as &apos;</source>
         <translation>Virhe tallennettaessa rataa &apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="715"/>
+        <location filename="../mainwindow.cpp" line="642"/>
         <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
         <translation>Uusi rata &apos;%1&apos; luotu. Sarakkeita: %2, Rivejä: %3.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="751"/>
+        <location filename="../mainwindow.cpp" line="729"/>
         <source>Track properties updated.</source>
         <translation>Radan ominaisuudet päivitetty.</translation>
     </message>
@@ -244,17 +248,17 @@
         <translation type="vanished">Indeksi asetettu arvoon &apos;%1&apos;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="794"/>
+        <location filename="../mainwindow.cpp" line="572"/>
         <source>Set route: begin.</source>
         <translation>Aseta reitti: alku.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="797"/>
+        <location filename="../mainwindow.cpp" line="575"/>
         <source>Set route, checkpoints and driving lines.</source>
         <translation>Aseta reitti, tarkastuspisteet ja ajolinjat.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="798"/>
+        <location filename="../mainwindow.cpp" line="576"/>
         <source>Setting the route defines checkpoints for the cars so
 that no shortcuts can be taken. It also defines
 driving lines for the computer players.
@@ -273,22 +277,22 @@ Klikkaa ensimmäistä asettamaasi solmupistettä lopettaaksesi.
 </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="810"/>
+        <location filename="../mainwindow.cpp" line="588"/>
         <source>Set route</source>
         <translation>Aseta reitti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="810"/>
+        <location filename="../mainwindow.cpp" line="588"/>
         <source>Invalid track. Route cannot be set.</source>
         <translation>Epäkelpo rata. Reittiä ei voitu asettaa.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="811"/>
+        <location filename="../mainwindow.cpp" line="587"/>
         <source>Set route: not a valid track.</source>
         <translation>Aseta reitti: rata ei validi. </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="820"/>
+        <location filename="../mainwindow.cpp" line="614"/>
         <source>Set route: route finished.</source>
         <translation>Aseta reitti: reitti valmis.</translation>
     </message>
@@ -338,7 +342,7 @@ Klikkaa ensimmäistä asettamaasi solmupistettä lopettaaksesi.
         <translation type="vanished">Laatat tyhjennetty.</translation>
     </message>
     <message>
-        <location filename="../editordata.cpp" line="427"/>
+        <location filename="../editordata.cpp" line="377"/>
         <source>Route cleared.</source>
         <translation>Reitti tyhjennetty.</translation>
     </message>
@@ -346,83 +350,83 @@ Klikkaa ensimmäistä asettamaasi solmupistettä lopettaaksesi.
 <context>
     <name>QWidget</name>
     <message>
-        <location filename="../editorview.cpp" line="117"/>
-        <location filename="../editorview.cpp" line="129"/>
+        <location filename="../editorview.cpp" line="95"/>
+        <location filename="../editorview.cpp" line="107"/>
         <source>Rotate 90</source>
         <translation>Pyöritä 90</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="117"/>
+        <location filename="../editorview.cpp" line="95"/>
         <source> CW..</source>
         <translation>Myötäpäivään..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="129"/>
+        <location filename="../editorview.cpp" line="107"/>
         <source> CCW..</source>
         <translation>Vastapäivään..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="141"/>
+        <location filename="../editorview.cpp" line="119"/>
         <source>Clear computer hint</source>
         <translation>Tyhjennä tietokonevihje</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="148"/>
+        <location filename="../editorview.cpp" line="126"/>
         <source>Set computer hint &apos;brake hard&apos;..</source>
         <translation>Aseta tietokonevihje &apos;jarruta voimakkaasti&apos;..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="155"/>
+        <location filename="../editorview.cpp" line="133"/>
         <source>Set computer hint &apos;brake&apos;..</source>
         <translation>Aseta tietokonevihje &apos;jarruta&apos;..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="162"/>
+        <location filename="../editorview.cpp" line="140"/>
         <source>Exclude from minimap</source>
         <translation>Älä näytä kartassa</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="173"/>
+        <location filename="../editorview.cpp" line="151"/>
         <source>Insert row before..</source>
         <translation>Lisää rivi ennen..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="183"/>
+        <location filename="../editorview.cpp" line="160"/>
         <source>Insert row after..</source>
         <translation>Lisää rivi jälkeen..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="193"/>
+        <location filename="../editorview.cpp" line="169"/>
         <source>Delete row..</source>
         <translation>Poista rivi..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="205"/>
+        <location filename="../editorview.cpp" line="178"/>
         <source>Insert column before..</source>
         <translation>Lisää sarake ennen..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="215"/>
+        <location filename="../editorview.cpp" line="187"/>
         <source>Insert column after..</source>
         <translation>Lisää sarake jälkeen..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="225"/>
+        <location filename="../editorview.cpp" line="196"/>
         <source>Delete column..</source>
         <translation>Poista sarake..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="257"/>
+        <location filename="../editorview.cpp" line="225"/>
         <source>Rotate..</source>
         <translation>Pyöritä..</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="272"/>
+        <location filename="../editorview.cpp" line="240"/>
         <source>Force stationary</source>
-        <translation type="unfinished"></translation>
+        <translation>Pakota liikkumattomaksi</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="291"/>
+        <location filename="../editorview.cpp" line="259"/>
         <source>Set size..</source>
         <translation>Aseta koko..</translation>
     </message>
