@@ -12,98 +12,104 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="76"/>
+        <location filename="../mainwindow.cpp" line="64"/>
         <source>Randomly rotate objects</source>
         <translation>Orienter les objets aléatoirement</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="111"/>
+        <location filename="../mainwindow.cpp" line="99"/>
         <source>Loading &apos;%1&apos;..</source>
         <translation>Chargement de &quot;%1&quot;...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="93"/>
         <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
         <translation>Choisissez &quot;Fichier -&gt; Nouveau&quot; ou &quot;Fichier -&gt; Ouvrir&quot; pour commencer.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="129"/>
+        <location filename="../mainwindow.cpp" line="120"/>
         <source>Save your work to correct location.</source>
         <translation>Enregistrez votre travail au bon endroit.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../mainwindow.cpp" line="134"/>
         <source>To make the game find your circuits, save them to %1%2%3%2</source>
         <translation>Pour que le jeu détecte vos circuits, enregistrez-les dans %1%2%3%2</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="136"/>
-        <location filename="../mainwindow.cpp" line="720"/>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <source>, %4%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="143"/>
+        <location filename="../mainwindow.cpp" line="636"/>
         <source>New file</source>
         <translation>Nouveau fichier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="182"/>
+        <location filename="../mainwindow.cpp" line="189"/>
         <source>Scale:</source>
         <translation>Échelle :</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="235"/>
+        <location filename="../mainwindow.cpp" line="241"/>
         <source>ERROR!!: Cannot load objects from &apos;</source>
         <translation>ERREUR : Impossible de charger les objets de &quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="236"/>
+        <location filename="../mainwindow.cpp" line="241"/>
         <source>&apos;</source>
         <translation>&quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="304"/>
+        <location filename="../mainwindow.cpp" line="291"/>
         <source>Scale set to %1%</source>
         <translation>Échelle définie à %1 %.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="323"/>
+        <location filename="../mainwindow.cpp" line="310"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="326"/>
+        <location filename="../mainwindow.cpp" line="313"/>
         <source>&amp;New...</source>
         <translation>&amp;Nouveau...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="332"/>
+        <location filename="../mainwindow.cpp" line="319"/>
         <source>&amp;Open...</source>
         <translation>&amp;Ouvrir...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="338"/>
+        <location filename="../mainwindow.cpp" line="325"/>
         <source>&amp;Save</source>
         <translation>&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="345"/>
+        <location filename="../mainwindow.cpp" line="332"/>
         <source>&amp;Save as...</source>
         <translation>&amp;Enregistrer sous...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="352"/>
+        <location filename="../mainwindow.cpp" line="339"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="358"/>
+        <location filename="../mainwindow.cpp" line="345"/>
         <source>&amp;Edit</source>
         <translation>&amp;Édition</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../mainwindow.cpp" line="348"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>Redo</source>
         <translation>Refaire</translation>
     </message>
@@ -112,130 +118,128 @@
         <translation type="vanished">Tout &amp;effacer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
         <source>Enlarge hor size</source>
-        <translation>Augmenter la taille horizontale</translation>
+        <translation type="vanished">Augmenter la taille horizontale</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="395"/>
         <source>Enlarge ver size</source>
-        <translation>Augmenter la taille verticale</translation>
+        <translation type="vanished">Augmenter la taille verticale</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="401"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>&amp;Set properties..</source>
         <translation>Définir les &amp;propriétés...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="407"/>
+        <location filename="../mainwindow.cpp" line="382"/>
         <source>&amp;Route</source>
         <translation>&amp;Parcours</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="410"/>
+        <location filename="../mainwindow.cpp" line="385"/>
         <source>Clear &amp;route</source>
         <translation>&amp;Effacer le parcours</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="416"/>
+        <location filename="../mainwindow.cpp" line="391"/>
         <source>&amp;Set route..</source>
         <translation>&amp;Définir le parcours...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="422"/>
+        <location filename="../mainwindow.cpp" line="397"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="../mainwindow.cpp" line="400"/>
         <source>&amp;About</source>
         <translation>&amp;À propos</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="430"/>
+        <location filename="../mainwindow.cpp" line="405"/>
         <source>About &amp;Qt</source>
         <translation>À propos de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="438"/>
+        <location filename="../mainwindow.cpp" line="413"/>
         <source>Select</source>
         <translation>Sélectionner</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../mainwindow.cpp" line="419"/>
         <source>Erase object</source>
         <translation>Effacer l&apos;objet</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="449"/>
+        <location filename="../mainwindow.cpp" line="424"/>
         <source>Clear</source>
         <translation>Effacer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
+        <location filename="../mainwindow.cpp" line="498"/>
         <source>Open a track</source>
         <translation>Ouvrir un circuit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="523"/>
-        <location filename="../mainwindow.cpp" line="660"/>
+        <location filename="../mainwindow.cpp" line="498"/>
+        <location filename="../mainwindow.cpp" line="683"/>
         <source>Track Files (*.trk)</source>
         <translation>Fichiers de circuits (*.trk)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="537"/>
+        <location filename="../mainwindow.cpp" line="512"/>
         <source>About Qt</source>
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="552"/>
+        <location filename="../mainwindow.cpp" line="526"/>
         <source>ERROR!!: %1 doesn&apos;t exist.</source>
         <translation>ERREUR : %1 n&apos;existe pas.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="564"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source>Track &apos;%1&apos; opened.</source>
         <translation>Circuit &quot;%1&quot; ouvert.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="599"/>
+        <location filename="../mainwindow.cpp" line="561"/>
         <source>Failed to open track &apos;</source>
         <translation>Échec d&apos;ouverture du circuit &quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
-        <location filename="../mainwindow.cpp" line="671"/>
+        <location filename="../mainwindow.cpp" line="663"/>
+        <location filename="../mainwindow.cpp" line="693"/>
         <source>Track &apos;</source>
         <translation>Circuit &quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
-        <location filename="../mainwindow.cpp" line="671"/>
+        <location filename="../mainwindow.cpp" line="663"/>
+        <location filename="../mainwindow.cpp" line="693"/>
         <source>&apos; saved.</source>
         <translation>&quot; enregistré.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="646"/>
+        <location filename="../mainwindow.cpp" line="669"/>
         <source>Failed to save track &apos;</source>
         <translation>Échec d&apos;enregistrement du circuit &quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="658"/>
+        <location filename="../mainwindow.cpp" line="681"/>
         <source>Save a track</source>
         <translation>Enregistrer un circuit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="677"/>
+        <location filename="../mainwindow.cpp" line="699"/>
         <source>Failed to save track as &apos;</source>
         <translation>Échec d&apos;enregistrement du circuit dans &quot;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="715"/>
+        <location filename="../mainwindow.cpp" line="642"/>
         <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
         <translation>Un nouveau circuit &quot;%1&quot; a été créé. Colonnes : %2, Lignes : %3.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="751"/>
+        <location filename="../mainwindow.cpp" line="729"/>
         <source>Track properties updated.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -244,17 +248,17 @@
         <translation type="vanished">Index défini à &quot;%1&quot;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="794"/>
+        <location filename="../mainwindow.cpp" line="572"/>
         <source>Set route: begin.</source>
         <translation>Définition du parcours : départ.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="797"/>
+        <location filename="../mainwindow.cpp" line="575"/>
         <source>Set route, checkpoints and driving lines.</source>
         <translation>Définir le parcours, les points de contrôle et les trajectoires</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="798"/>
+        <location filename="../mainwindow.cpp" line="576"/>
         <source>Setting the route defines checkpoints for the cars so
 that no shortcuts can be taken. It also defines
 driving lines for the computer players.
@@ -277,22 +281,22 @@ des tours et le timing fonctionnent correctement.
 Cliquez à nouveau sur le premier nœud pour fermer la boucle.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="810"/>
+        <location filename="../mainwindow.cpp" line="588"/>
         <source>Set route</source>
         <translation>Définir le parcours</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="810"/>
+        <location filename="../mainwindow.cpp" line="588"/>
         <source>Invalid track. Route cannot be set.</source>
         <translation>Circuit invalide. Le parcours ne peut pas être défini.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="811"/>
+        <location filename="../mainwindow.cpp" line="587"/>
         <source>Set route: not a valid track.</source>
         <translation>Définition du parcours : le circuit n&apos;est pas valide.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="820"/>
+        <location filename="../mainwindow.cpp" line="614"/>
         <source>Set route: route finished.</source>
         <translation>Définition du parcours : parcours terminé.</translation>
     </message>
@@ -342,7 +346,7 @@ Cliquez à nouveau sur le premier nœud pour fermer la boucle.</translation>
         <translation type="vanished">Cases supprimées.</translation>
     </message>
     <message>
-        <location filename="../editordata.cpp" line="427"/>
+        <location filename="../editordata.cpp" line="377"/>
         <source>Route cleared.</source>
         <translation>Parcours supprimé.</translation>
     </message>
@@ -350,83 +354,83 @@ Cliquez à nouveau sur le premier nœud pour fermer la boucle.</translation>
 <context>
     <name>QWidget</name>
     <message>
-        <location filename="../editorview.cpp" line="117"/>
-        <location filename="../editorview.cpp" line="129"/>
+        <location filename="../editorview.cpp" line="95"/>
+        <location filename="../editorview.cpp" line="107"/>
         <source>Rotate 90</source>
         <translation>Tourner de 90</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="117"/>
+        <location filename="../editorview.cpp" line="95"/>
         <source> CW..</source>
         <translation> (sens horaire)</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="129"/>
+        <location filename="../editorview.cpp" line="107"/>
         <source> CCW..</source>
         <translation> (sens anti-horaire)</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="141"/>
+        <location filename="../editorview.cpp" line="119"/>
         <source>Clear computer hint</source>
         <translation>Supprimer l&apos;indice pour l&apos;ordinateur</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="148"/>
+        <location filename="../editorview.cpp" line="126"/>
         <source>Set computer hint &apos;brake hard&apos;..</source>
         <translation>Définir l&apos;indice &quot;Freiner fortement&quot; pour l&apos;ordinateur</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="155"/>
+        <location filename="../editorview.cpp" line="133"/>
         <source>Set computer hint &apos;brake&apos;..</source>
         <translation>Définir l&apos;indice &quot;Freiner&quot; pour l&apos;ordinateur</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="162"/>
+        <location filename="../editorview.cpp" line="140"/>
         <source>Exclude from minimap</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="173"/>
+        <location filename="../editorview.cpp" line="151"/>
         <source>Insert row before..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="183"/>
+        <location filename="../editorview.cpp" line="160"/>
         <source>Insert row after..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="193"/>
+        <location filename="../editorview.cpp" line="169"/>
         <source>Delete row..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="205"/>
+        <location filename="../editorview.cpp" line="178"/>
         <source>Insert column before..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="215"/>
+        <location filename="../editorview.cpp" line="187"/>
         <source>Insert column after..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="225"/>
+        <location filename="../editorview.cpp" line="196"/>
         <source>Delete column..</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="257"/>
+        <location filename="../editorview.cpp" line="225"/>
         <source>Rotate..</source>
         <translation>Tourner...</translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="272"/>
+        <location filename="../editorview.cpp" line="240"/>
         <source>Force stationary</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../editorview.cpp" line="291"/>
+        <location filename="../editorview.cpp" line="259"/>
         <source>Set size..</source>
         <translation>Définir la taille...</translation>
     </message>
