@@ -17,36 +17,35 @@
 #define BRIDGE_HPP
 
 #include <MCObject>
-
 #include <map>
 
 class MCCollisionEvent;
+class MCSeparationEvent;
 class MCSurface;
-class Car;
 
 class Bridge : public MCObject
 {
 public:
-
     Bridge();
 
     //! \reimp
     virtual void collisionEvent(MCCollisionEvent & event) override;
 
     //! \reimp
-    virtual void onStepTime(int step) override;
+    virtual void separationEvent(MCSeparationEvent & event) override;
 
-    void enterObject(MCObject & object);
+    void objectUnderBridge(MCObject & object, bool isUnder);
+
+    static void reset();
 
 private:
+    void doExitObject(MCObject & object);
 
     void raiseObject(MCObject & object, bool raise);
 
-    std::map<MCObject *, int> m_objectsOnBridge;
-
-    std::map<MCObject *, bool> m_objectsEntered;
-
-    int m_tag;
+    using ObjectStatusMap = std::map<MCObject *, std::set<Bridge *>>;
+    static ObjectStatusMap m_onBridgeStatusMap;
+    static ObjectStatusMap m_underBridgeStatusMap;
 };
 
 #endif // BRIDGE_HPP
