@@ -18,13 +18,14 @@
 
 #include "overlaybase.hpp"
 
+#include <memory>
+
 class MCSurface;
 
 //! Renders checkerflag on top of the game scene.
 class CheckeredFlag : public OverlayBase
 {
 public:
-
     //! Constructor.
     CheckeredFlag();
 
@@ -32,8 +33,7 @@ public:
     virtual void render() override;
 
 private:
-
-    MCSurface & m_surface;
+    std::shared_ptr<MCSurface> m_surface;
 };
 
 #endif // CHECKEREDFLAG_HPP
