@@ -18,20 +18,21 @@
 
 #include "overlaybase.hpp"
 
+#include <memory>
+
 class MCSurface;
 class Car;
 
 class CrashOverlay : public OverlayBase
 {
 public:
-
     CrashOverlay();
 
     //! \reimp
     virtual void render() override;
 
     //! \reimp
-    virtual void setDimensions(int width, int height) override;
+    virtual void setDimensions(size_t width, size_t height) override;
 
     //! \reimp
     virtual bool update() override;
@@ -39,8 +40,7 @@ public:
     void setCarToFollow(Car & car);
 
 private:
-
-    MCSurface & m_surface;
+    std::shared_ptr<MCSurface> m_surface;
 
     float m_alpha;
 
