@@ -19,9 +19,11 @@
 #include <MCObject>
 #include <QObject>
 
-#include <map>
+#include <memory>
+#include <set>
 
 class MCCollisionEvent;
+class MCSeparationEvent;
 class MCSurface;
 class Car;
 
@@ -31,13 +33,17 @@ class Pit : public QObject, public MCObject
     Q_OBJECT
 
 public:
-
     //! Constructor.
-    Pit(MCSurface & surface);
+    Pit(std::shared_ptr<MCSurface> surface);
+
+    void reset();
 
     //! \reimp
     virtual void collisionEvent(MCCollisionEvent & event) override;
 
+    //! \reimp
+    virtual void separationEvent(MCSeparationEvent & event) override;
+
     //! \reimp
     virtual void onStepTime(int step) override;
 
@@ -46,9 +52,7 @@ signals:
     void pitStop(Car & car);
 
 private:
-
-    std::map<Car *, int> m_pittingCars;
-    int                  m_tag;
+    std::set<Car *> m_possiblyPittingCars;
 };
 
 #endif // PIT_HPP
