@@ -32,8 +32,8 @@
 
 #include <algorithm>
 #include <cassert>
+#include <random>
 
-#include <MCLogger>
 #include <MCAssetManager>
 #include <MCObjectFactory>
 #include <MCPhysicsComponent>
@@ -41,41 +41,43 @@
 #include <MCShapeView>
 #include <MCSurfaceManager>
 
-static const int HUMAN_PLAYER_INDEX1 = 0;
-static const int HUMAN_PLAYER_INDEX2 = 1;
-static const int UNLOCK_LIMIT        = 6; // Position required to unlock a new track
+#include "simple_logger.hpp"
 
-Race::Race(Game & game, unsigned int numCars)
-: m_numCars(numCars)
-, m_lapCount(5)
-, m_timing(numCars)
-, m_track(nullptr)
-, m_started(false)
-, m_checkeredFlagEnabled(false)
-, m_winnerFinished(false)
-, m_isfinishedSignalSent(false)
-, m_bestPos(-1)
-, m_offTrackCounter(0)
-, m_game(game)
+Race::Race(Game & game, size_t numCars)
+  : m_humanPlayerIndex1(0)
+  , m_humanPlayerIndex2(1)
+  , m_unlockLimit(6) // Position required to unlock a new track
+  , m_numCars(numCars)
+  , m_lapCount(5)
+  , m_timing(numCars)
+  , m_track(nullptr)
+  , m_started(false)
+  , m_checkeredFlagEnabled(false)
+  , m_winnerFinished(false)
+  , m_isfinishedSignalSent(false)
+  , m_bestPos(-1)
+  , m_offTrackCounter(0)
+  , m_game(game)
 {
     createStartGridObjects();
 
     m_offTrackMessageTimer.setSingleShot(true);
     m_offTrackMessageTimer.setInterval(30000);
 
-    connect(&m_timing, &Timing::lapRecordAchieved, [this] (int msecs) {
+    connect(&m_timing, &Timing::lapRecordAchieved, [this](int msecs) {
         Settings::instance().saveLapRecord(*m_track, msecs);
         emit messageRequested(QObject::tr("New lap record!"));
     });
 
-    connect(&m_timing, &Timing::raceRecordAchieved, [this] (int msecs) {
-        if (m_game.hasComputerPlayers()) {
-            Settings::instance().saveRaceRecord(*m_track, msecs, m_lapCount, m_game.difficultyProfile().difficulty());
+    connect(&m_timing, &Timing::raceRecordAchieved, [this](int msecs) {
+        if (m_game.hasComputerPlayers())
+        {
+            Settings::instance().saveRaceRecord(*m_track, msecs, static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty());
             emit messageRequested(QObject::tr("New race record!"));
         }
     });
 
-    connect(&m_timing, &Timing::lapCompleted, [this] (unsigned int, int msecs) {
+    connect(&m_timing, &Timing::lapCompleted, [this](size_t, int msecs) {
         emit messageRequested(QString::fromWCharArray(Timing::msecsToString(msecs).c_str()));
     });
 }
@@ -83,13 +85,13 @@ Race::Race(Game & game, unsigned int numCars)
 void Race::createStartGridObjects()
 {
     static MCObjectFactory objectFactory(MCAssetManager::instance());
-    for (int i = 0; i < m_numCars; i++)
+    for (size_t i = 0; i < m_numCars; i++)
     {
         MCSurfaceObjectData data("grid");
         data.setIsStationary(true);
         data.setSurfaceId("grid");
 
-        MCObjectPtr object = objectFactory.build(data);
+        const auto object = objectFactory.build(data);
         object->shape()->view()->setHasShadow(false);
         object->setIsPhysicsObject(false);
 
@@ -97,7 +99,7 @@ void Race::createStartGridObjects()
     }
 }
 
-void Race::init(Track & track, int lapCount)
+void Race::init(std::shared_ptr<Track> track, size_t lapCount)
 {
     setTrack(track, lapCount);
 
@@ -111,7 +113,7 @@ void Race::init(Track & track, int lapCount)
 void Race::initTiming()
 {
     m_timing.setLapRecord(Settings::instance().loadLapRecord(*m_track));
-    m_timing.setRaceRecord(Settings::instance().loadRaceRecord(*m_track, m_lapCount, m_game.difficultyProfile().difficulty()));
+    m_timing.setRaceRecord(Settings::instance().loadRaceRecord(*m_track, static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty()));
     m_timing.reset();
 }
 
@@ -119,16 +121,15 @@ void Race::initCars()
 {
     translateCarsToStartPositions();
 
+    m_statusHash.clear();
+
     for (auto && car : m_cars)
     {
-        car->setNextTargetNodeIndex(0);
-        car->setCurrentTargetNodeIndex(0);
-        car->setPrevTargetNodeIndex(0);
-        car->setRouteProgression(0);
         car->resetDamage();
         car->resetTireWear();
 
         m_stuckHash[car->index()] = StuckTileCounter(nullptr, 0);
+        m_statusHash[car->index()] = CarStatus {};
 
         if (car->soundEffectManager())
         {
@@ -140,47 +141,41 @@ void Race::initCars()
 void Race::clearPositions()
 {
     m_progression.clear();
-
-    for (auto && car : m_cars) {
-        car->setPosition(0);
-    }
 }
 
 void Race::clearRaceFlags()
 {
     m_checkeredFlagEnabled = false;
-    m_winnerFinished       = false;
+    m_winnerFinished = false;
     m_isfinishedSignalSent = false;
-    m_started              = false;
+    m_started = false;
 }
 
 void placeCar(Car & car, float x, float y, int angle)
 {
-    car.translate(MCVector2d<float>(x, y));
+    car.translate({ x, y });
     car.rotate(angle);
+
+    juzzlin::L().debug() << "Car " << car.index() << " location: " << car.location();
+    juzzlin::L().debug() << "Car " << car.index() << " rotation: " << car.angle();
 }
 
 void placeStartGrid(MCObject & grid, float x, float y, int angle)
 {
-    grid.translate(MCVector2dF(x, y));
+    grid.translate({ x, y });
     grid.rotate(angle);
     grid.addToWorld();
+
+    juzzlin::L().debug() << "Start grid location: " << grid.location();
+    juzzlin::L().debug() << "Start grid rotation: " << grid.angle();
 }
 
 void Race::translateCarsToStartPositions()
 {
     assert(m_track);
 
-    if (TrackTilePtr finishLine = m_track->finishLine())
+    if (auto finishLine = m_track->finishLine())
     {
-        const float startTileX = finishLine->location().x();
-        const float startTileY = finishLine->location().y();
-        const float tileWidth  = TrackTile::TILE_W;
-        const float tileHeight = TrackTile::TILE_H;
-        const float spacing    = 0.75 * TrackTile::TILE_W;
-        const float oddOffset  = TrackTile::TILE_W / 8;
-        const float gridOffset = 24;
-
         // Reverse order
         auto order = m_cars;
         std::reverse(order.begin(), order.end());
@@ -189,7 +184,7 @@ void Race::translateCarsToStartPositions()
         // of the current race track.
         if (m_game.hasComputerPlayers() && !m_game.hasTwoHumanPlayers())
         {
-            const int bestPos = Settings::instance().loadBestPos(*m_track, m_lapCount, m_game.difficultyProfile().difficulty());
+            const int bestPos = Settings::instance().loadBestPos(*m_track, static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty());
             if (bestPos > 0)
             {
                 order.insert(order.begin() + bestPos - 1, *m_cars.begin());
@@ -198,58 +193,94 @@ void Race::translateCarsToStartPositions()
         }
 
         // Position the cars into two queues.
+        const float oddOffset = TrackTile::width() / 8;
+        const float gridOffset = TrackTile::width() / 12;
+        const float tileWidth = static_cast<float>(TrackTile::width());
+        const float tileHeight = static_cast<float>(TrackTile::height());
+        const float spacing = 0.75f * TrackTile::width();
+        const float startTileX = static_cast<float>(finishLine->location().x());
+        const float startTileY = static_cast<float>(finishLine->location().y());
         const int routeDirection = finishLine->rotation() % 360;
+        juzzlin::L().debug() << "Route direction: " << routeDirection;
         switch (routeDirection)
         {
         case 90:
         case -270:
-            for (unsigned int i = 0; i < order.size(); i++)
+        {
+            float moveDueToBridge = 0;
+            for (size_t i = 0; i < order.size(); i++)
             {
-                const float rowPos = (i / 2) * spacing + (i % 2) * oddOffset;
-                const float colPos = (i % 2) * tileHeight / 3 - tileHeight / 6;
-                placeCar(*order.at(i), startTileX + rowPos, startTileY + colPos, 180);
-                placeStartGrid(*m_startGridObjects.at(i), startTileX + rowPos - gridOffset, startTileY + colPos, 180);
+                const float y = startTileY + (i % 2) * tileHeight / 3 - tileHeight / 6;
+                float x = startTileX + (i / 2) * spacing + (i % 2) * oddOffset + moveDueToBridge;
+                while (m_track->trackTileAtLocation(x, y)->tileTypeEnum() == TrackTile::TileType::Bridge)
+                {
+                    moveDueToBridge += tileWidth;
+                    x += moveDueToBridge;
+                }
+                placeCar(*order.at(i), x, y, 180);
+                placeStartGrid(*m_startGridObjects.at(i), x - gridOffset, y, 180);
             }
             break;
-
+        }
         default:
         case 270:
         case -90:
-            for (unsigned int i = 0; i < order.size(); i++)
+        {
+            float moveDueToBridge = 0;
+            for (size_t i = 0; i < order.size(); i++)
             {
-                const float rowPos = (i / 2) * spacing + (i % 2) * oddOffset;
-                const float colPos = (i % 2) * tileHeight / 3 - tileHeight / 6;
-                placeCar(*order.at(i), startTileX - rowPos, startTileY + colPos, 0);
-                placeStartGrid(*m_startGridObjects.at(i), startTileX - rowPos + gridOffset, startTileY + colPos, 0);
+                const float y = startTileY + (i % 2) * tileHeight / 3 - tileHeight / 6;
+                float x = startTileX - (i / 2) * spacing + (i % 2) * oddOffset - moveDueToBridge;
+                while (m_track->trackTileAtLocation(x, y)->tileTypeEnum() == TrackTile::TileType::Bridge)
+                {
+                    moveDueToBridge += tileWidth;
+                    x -= moveDueToBridge;
+                }
+                placeCar(*order.at(i), x, y, 0);
+                placeStartGrid(*m_startGridObjects.at(i), x + gridOffset, y, 0);
             }
             break;
-
+        }
         case 0:
-            for (unsigned int i = 0; i < order.size(); i++)
+        {
+            float moveDueToBridge = 0;
+            for (size_t i = 0; i < order.size(); i++)
             {
-                const float rowPos = (i % 2) * tileWidth / 3 - tileWidth / 6;
-                const float colPos = (i / 2) * spacing + (i % 2) * oddOffset;
-                placeCar(*order.at(i), startTileX + rowPos, startTileY - colPos, 90);
-                placeStartGrid(*m_startGridObjects.at(i), startTileX + rowPos, startTileY - colPos + gridOffset, 90);
+                const float x = startTileX + (i % 2) * tileWidth / 3 - tileWidth / 6;
+                float y = startTileY - (i / 2) * spacing + (i % 2) * oddOffset - moveDueToBridge;
+                while (m_track->trackTileAtLocation(x, y)->tileTypeEnum() == TrackTile::TileType::Bridge)
+                {
+                    moveDueToBridge += tileHeight;
+                    y -= moveDueToBridge;
+                }
+                placeCar(*order.at(i), x, y, 90);
+                placeStartGrid(*m_startGridObjects.at(i), x, y + gridOffset, 90);
             }
             break;
-
+        }
         case 180:
         case -180:
-            for (unsigned int i = 0; i < order.size(); i++)
+        {
+            float moveDueToBridge = 0;
+            for (size_t i = 0; i < order.size(); i++)
             {
-                const float rowPos = (i % 2) * tileWidth  / 3 - tileWidth / 6;
-                const float colPos = (i / 2) * spacing + (i % 2) * oddOffset;
-                placeCar(*order.at(i), startTileX + rowPos, startTileY + colPos, 270);
-                placeStartGrid(*m_startGridObjects.at(i), startTileX + rowPos, startTileY + colPos - gridOffset, 270);
+                const float x = startTileX + (i % 2) * tileWidth / 3 - tileWidth / 6;
+                float y = startTileY + (i / 2) * spacing + (i % 2) * oddOffset + moveDueToBridge;
+                while (m_track->trackTileAtLocation(x, y)->tileTypeEnum() == TrackTile::TileType::Bridge)
+                {
+                    moveDueToBridge += tileHeight;
+                    y += moveDueToBridge;
+                }
+                placeCar(*order.at(i), x, y, 270);
+                placeStartGrid(*m_startGridObjects.at(i), x, y - gridOffset, 270);
             }
             break;
         }
+        }
     }
     else
     {
-        MCLogger().error() << "Finish line tile not found in track '" <<
-            m_track->trackData().name().toStdString() << "'";
+        juzzlin::L().error() << "Finish line tile not found in track '" << m_track->trackData().name().toStdString() << "'";
     }
 }
 
@@ -258,13 +289,13 @@ void Race::start()
     if (!m_started)
     {
         m_timing.start();
-        m_started  = true;
+        m_started = true;
     }
 }
 
 void Race::stopEngineSounds()
 {
-    for(auto && car : m_cars)
+    for (auto && car : m_cars)
     {
         if (car->soundEffectManager())
         {
@@ -288,11 +319,9 @@ void Race::update()
     // Enable the checkered flag if leader has done at least 95% of the last lap.
     if (m_timing.leadersLap() + 1 == m_lapCount)
     {
-        auto && leader = getLeader();
         auto && route = m_track->trackData().route();
-        auto tnode = route.get(leader.currentTargetNodeIndex());
-
-        if (tnode->index() >= static_cast<int>(9 * route.numNodes() / 10))
+        auto && targetNode = route.get(m_statusHash[getLeader().index()].currentTargetNodeIndex);
+        if (targetNode->index() >= static_cast<int>(9 * route.numNodes() / 10))
         {
             if (!m_checkeredFlagEnabled)
             {
@@ -325,7 +354,7 @@ void Race::update()
         }
     }
 
-    for (OffTrackDetectorPtr otd : m_offTrackDetectors)
+    for (auto && otd : m_offTrackDetectors)
     {
         otd->update();
     }
@@ -354,24 +383,24 @@ void Race::pitStop(Car & car)
     }
 }
 
-bool isInsideCheckPoint(Car & car, TargetNodeBasePtr tnode, int tolerance)
+bool isInsideCheckPoint(Car & car, TargetNodeBasePtr targetNode, size_t tolerance)
 {
-    const int width2  = tnode->size().width()  / 2;
-    const int height2 = tnode->size().height() / 2;
+    const int halfWidth = static_cast<int>(targetNode->size().width() / 2);
+    const int halfHeight = static_cast<int>(targetNode->size().height() / 2);
 
-    if (car.location().i() < tnode->location().x() - width2 - tolerance)
+    if (car.location().i() < static_cast<float>(targetNode->location().x()) - halfWidth - tolerance)
     {
         return false;
     }
-    else if (car.location().i() > tnode->location().x() + width2 + tolerance)
+    else if (car.location().i() > static_cast<float>(targetNode->location().x()) + halfWidth + tolerance)
     {
         return false;
     }
-    else if (car.location().j() < tnode->location().y() - height2 - tolerance)
+    else if (car.location().j() < static_cast<float>(targetNode->location().y()) - halfHeight - tolerance)
     {
         return false;
     }
-    else if (car.location().j() > tnode->location().y() + height2 + tolerance)
+    else if (car.location().j() > static_cast<float>(targetNode->location().y()) + halfHeight + tolerance)
     {
         return false;
     }
@@ -382,11 +411,12 @@ bool isInsideCheckPoint(Car & car, TargetNodeBasePtr tnode, int tolerance)
 void Race::updateRouteProgress(Car & car)
 {
     auto && route = m_track->trackData().route();
-    unsigned int currentTargetNodeIndex = car.currentTargetNodeIndex();
-    unsigned int nextTargetNodeIndex = car.nextTargetNodeIndex();
-    auto tnode = route.get(currentTargetNodeIndex);
+    size_t currentTargetNodeIndex = m_statusHash[car.index()].currentTargetNodeIndex;
+    size_t nextTargetNodeIndex = m_statusHash[car.index()].nextTargetNodeIndex;
+    const auto targetNode = route.get(currentTargetNodeIndex);
+
     // Give a bit more tolerance for other than the finishing check point.
-    const int tolerance = (currentTargetNodeIndex == 0 ? 0 : TrackTile::TILE_H / 20);
+    const size_t tolerance = (!currentTargetNodeIndex ? 0 : TrackTile::height() / 20);
 
     // Car still racing
     if (m_timing.isActive(car.index()))
@@ -405,31 +435,31 @@ void Race::updateRouteProgress(Car & car)
                 checkIfCarIsOffTrack(car);
             }
 
-            if (isInsideCheckPoint(car, tnode, tolerance))
+            if (isInsideCheckPoint(car, targetNode, tolerance))
             {
                 updatePositions();
 
                 checkIfLapIsCompleted(car, route, currentTargetNodeIndex);
 
                 // Increase progress and update the positions hash
-                car.setRouteProgression(car.routeProgression() + 1);
-                m_progression[car.routeProgression()].push_back(car.index());
+                m_progression[++m_statusHash[car.index()].routeProgression].push_back(car.index());
 
                 // Switch to next check point
-                car.setPrevTargetNodeIndex(currentTargetNodeIndex);
+                m_statusHash[car.index()].prevTargetNodeIndex = currentTargetNodeIndex;
                 if (++currentTargetNodeIndex >= route.numNodes())
                 {
                     currentTargetNodeIndex = 0;
                 }
 
                 nextTargetNodeIndex = currentTargetNodeIndex;
-                if (++nextTargetNodeIndex >= route.numNodes()){
+                if (++nextTargetNodeIndex >= route.numNodes())
+                {
                     nextTargetNodeIndex = 0;
                 }
             }
 
-            car.setCurrentTargetNodeIndex(currentTargetNodeIndex);
-            car.setNextTargetNodeIndex(nextTargetNodeIndex);
+            m_statusHash[car.index()].currentTargetNodeIndex = currentTargetNodeIndex;
+            m_statusHash[car.index()].nextTargetNodeIndex = nextTargetNodeIndex;
         }
         else
         {
@@ -441,37 +471,37 @@ void Race::updateRouteProgress(Car & car)
     // Car has finished: cooldown laps
     else
     {
-        if (isInsideCheckPoint(car, tnode, tolerance))
+        if (isInsideCheckPoint(car, targetNode, tolerance))
         {
             // Switch to next check point
-            car.setPrevTargetNodeIndex(currentTargetNodeIndex);
+            m_statusHash[car.index()].prevTargetNodeIndex = currentTargetNodeIndex;
             if (++currentTargetNodeIndex >= route.numNodes())
             {
                 currentTargetNodeIndex = 0;
             }
 
             nextTargetNodeIndex = currentTargetNodeIndex;
-            if (++nextTargetNodeIndex >= route.numNodes()){
+            if (++nextTargetNodeIndex >= route.numNodes())
+            {
                 nextTargetNodeIndex = 0;
             }
         }
 
-        car.setCurrentTargetNodeIndex(currentTargetNodeIndex);
-        car.setNextTargetNodeIndex(nextTargetNodeIndex);
+        m_statusHash[car.index()].currentTargetNodeIndex = currentTargetNodeIndex;
+        m_statusHash[car.index()].nextTargetNodeIndex = nextTargetNodeIndex;
     }
 }
 
 void Race::updatePositions()
 {
-    CarVector positions = m_cars;
-
-    std::sort(positions.begin(), positions.end(), [=](Car * lhs, Car * rhs) -> bool {
+    auto positions = m_cars;
+    std::sort(positions.begin(), positions.end(), [this](auto lhs, auto rhs) -> bool {
         // Easy comparison: cars have reached different checkpoints
-        if (lhs->routeProgression() > rhs->routeProgression())
+        if (m_statusHash[lhs->index()].routeProgression > m_statusHash[rhs->index()].routeProgression)
         {
             return true;
         }
-        else if (lhs->routeProgression() < rhs->routeProgression())
+        else if (m_statusHash[lhs->index()].routeProgression < m_statusHash[rhs->index()].routeProgression)
         {
             return false;
         }
@@ -482,8 +512,8 @@ void Race::updatePositions()
             int lhsPos = 0;
             int rhsPos = 0;
             int pos = 0;
-            auto && progression = m_progression[lhs->routeProgression()];
-            for (int index : progression)
+            auto && progression = m_progression[m_statusHash[lhs->index()].routeProgression];
+            for (size_t index : progression)
             {
                 if (m_cars[index] == lhs)
                 {
@@ -502,18 +532,17 @@ void Race::updatePositions()
     });
 
     // Store current position to car objects for fast access
-    int pos = 1;
+    size_t position = 1;
     for (auto && car : positions)
     {
-        car->setPosition(pos);
-        pos++;
+        m_statusHash[car->index()].position = position;
+        position++;
     }
 }
 
-void Race::checkIfLapIsCompleted(Car & car, const Route & route, unsigned int currentTargetNodeIndex)
+void Race::checkIfLapIsCompleted(Car & car, const Route & route, size_t currentTargetNodeIndex)
 {
-    if (currentTargetNodeIndex == 0 &&
-        car.prevTargetNodeIndex() + 1 == static_cast<int>(route.numNodes()))
+    if (currentTargetNodeIndex == 0 && m_statusHash[car.index()].prevTargetNodeIndex + 1 == route.numNodes())
     {
         m_timing.setLapCompleted(car.index(), car.isHuman());
 
@@ -533,20 +562,20 @@ void Race::checkForNewBestPosition(const Car & car)
     {
         if (car.isHuman())
         {
-            const int pos = car.position();
-            if (pos < m_bestPos || m_bestPos == -1)
+            const size_t position = m_statusHash[car.index()].position;
+            if (static_cast<int>(position) < m_bestPos || m_bestPos == -1)
             {
-                Settings::instance().saveBestPos(*m_track, pos, m_lapCount, m_game.difficultyProfile().difficulty());
+                Settings::instance().saveBestPos(*m_track, static_cast<int>(position), static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty());
                 emit messageRequested(QObject::tr("A new best pos!"));
             }
 
-            auto next = m_track->next();
+            auto && next = m_track->next().lock();
             if (next && next->trackData().isLocked())
             {
-                if (pos <= UNLOCK_LIMIT)
+                if (position <= m_unlockLimit)
                 {
                     next->trackData().setIsLocked(false);
-                    Settings::instance().saveTrackUnlockStatus(*next, m_lapCount, m_game.difficultyProfile().difficulty());
+                    Settings::instance().saveTrackUnlockStatus(*next, static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty());
                     emit messageRequested(QObject::tr("A new track unlocked!"));
                 }
                 else
@@ -576,7 +605,7 @@ void Race::checkIfCarIsStuck(Car & car)
             if (++counter.second >= STUCK_LIMIT)
             {
                 moveCarOntoPreviousCheckPoint(car);
-                counter.first  = nullptr;
+                counter.first = nullptr;
                 counter.second = 0;
             }
         }
@@ -614,27 +643,34 @@ void Race::moveCarOntoPreviousCheckPoint(Car & car)
     // Randomize the target location a bit, because otherwise multiple
     // stuck cars could be sent to the exactly same location and that would
     // result in really bad things.
-    auto && route = m_track->trackData().route();
-    auto tnode = route.get(car.prevTargetNodeIndex());
-    const int randRadius = 64;
-    car.translate(MCVector3dF(
-        tnode->location().x() + rand() % randRadius - randRadius / 2,
-        tnode->location().y() + rand() % randRadius - randRadius / 2));
+    const auto targetNode = m_track->trackData().route().get(m_statusHash[car.index()].prevTargetNodeIndex);
+    const double randRadius = TrackTile::width() / 4;
+    std::mt19937 engine;
+    std::uniform_real_distribution<double> dist(-randRadius, randRadius);
+    const float x = static_cast<float>(targetNode->location().x() + dist(engine));
+    const float y = static_cast<float>(targetNode->location().y() + dist(engine));
+    car.translate({ x, y });
     car.physicsComponent().reset();
+    juzzlin::L().debug() << "Moved stuck car " << car.index() << " to (" << x << ", " << y << ")";
+}
+
+size_t Race::getCurrentTargetNodeIndex(const Car & car) const
+{
+    return m_statusHash.at(car.index()).currentTargetNodeIndex;
 }
 
 Car & Race::getLeader() const
 {
-    int bestPos = m_cars.size();
+    auto bestPos = m_cars.size();
     auto bestCar = m_cars.back();
 
-    for (unsigned int i = 0; i < m_cars.size(); i++)
+    for (auto && car : m_cars)
     {
-        const auto pos = m_cars[i]->position();
-        if (pos > 0 && pos < bestPos)
+        const auto position = m_statusHash.at(car->index()).position;
+        if (position > 0 && position < bestPos)
         {
-            bestCar = m_cars[i];
-            bestPos = pos;
+            bestCar = car;
+            bestPos = position;
         }
     }
 
@@ -643,35 +679,40 @@ Car & Race::getLeader() const
 
 Car & Race::getLoser() const
 {
-    int bestValue = 0;
+    size_t bestValue = 0;
     auto bestCar = m_cars.back();
 
     for (auto && car : m_cars)
     {
-        const int pos = car->position();
-        if (pos > bestValue)
+        const auto position = m_statusHash.at(car->index()).position;
+        if (position > bestValue)
         {
             bestCar = car;
-            bestValue = pos;
+            bestValue = position;
         }
     }
 
     return *bestCar;
 }
 
-void Race::setTrack(Track & track, int lapCount)
+size_t Race::position(const Car & car) const
+{
+    return m_statusHash.at(car.index()).position;
+}
+
+void Race::setTrack(std::shared_ptr<Track> track, size_t lapCount)
 {
     m_lapCount = lapCount;
-    m_track    = &track;
-    m_bestPos  = Settings::instance().loadBestPos(*m_track, m_lapCount, m_game.difficultyProfile().difficulty());
+    m_track = track;
+    m_bestPos = Settings::instance().loadBestPos(*m_track, static_cast<int>(m_lapCount), m_game.difficultyProfile().difficulty());
 
-    for (OffTrackDetectorPtr otd : m_offTrackDetectors)
+    for (auto && otd : m_offTrackDetectors)
     {
         otd->setTrack(track);
     }
 }
 
-int Race::lapCount() const
+size_t Race::lapCount() const
 {
     return m_lapCount;
 }
@@ -681,7 +722,7 @@ void Race::addCar(Car & car)
     if (find(m_cars.begin(), m_cars.end(), &car) == m_cars.end())
     {
         m_cars.push_back(&car);
-        m_offTrackDetectors.push_back(OffTrackDetectorPtr(new OffTrackDetector(car)));
+        m_offTrackDetectors.push_back(std::make_shared<OffTrackDetector>(car));
     }
 }
 
@@ -705,14 +746,10 @@ bool Race::isRaceFinished() const
 {
     if (m_game.hasTwoHumanPlayers())
     {
-        return
-            m_timing.raceCompleted(HUMAN_PLAYER_INDEX1) &&
-            m_timing.raceCompleted(HUMAN_PLAYER_INDEX2);
+        return m_timing.raceCompleted(m_humanPlayerIndex1) && m_timing.raceCompleted(m_humanPlayerIndex2);
     }
 
-    return m_timing.raceCompleted(HUMAN_PLAYER_INDEX1);
+    return m_timing.raceCompleted(m_humanPlayerIndex1);
 }
 
-Race::~Race()
-{
-}
+Race::~Race() = default;
