@@ -55,9 +55,8 @@
 #include <MCGLDiffuseLight>
 #include <MCGLScene>
 #include <MCGLShaderProgram>
-#include <MCLogger>
-#include <MCObjectFactory>
 #include <MCObject>
+#include <MCObjectFactory>
 #include <MCPhysicsComponent>
 #include <MCShape>
 #include <MCSurface>
@@ -67,8 +66,8 @@
 #include <MCWorld>
 #include <MCWorldRenderer>
 
-#include <QObject>
 #include <QApplication>
+#include <QObject>
 
 #include <algorithm>
 #include <cassert>
@@ -77,53 +76,63 @@
 using std::dynamic_pointer_cast;
 
 // Default visible scene size.
-int Scene::m_width  = 1024;
+int Scene::m_width = 1024;
 int Scene::m_height = 768;
 
 static const float METERS_PER_UNIT = 0.05f;
 
 Scene::Scene(Game & game, StateMachine & stateMachine, Renderer & renderer, MCWorld & world)
-: m_game(game)
-, m_stateMachine(stateMachine)
-, m_renderer(renderer)
-, m_messageOverlay(new MessageOverlay)
-, m_race(game, NUM_CARS)
-, m_activeTrack(nullptr)
-, m_world(world)
-, m_startlights(new Startlights)
-, m_startlightsOverlay(new StartlightsOverlay(*m_startlights))
-, m_checkeredFlag(new CheckeredFlag)
-, m_mainMenu(nullptr)
-, m_menuManager(nullptr)
-, m_intro(new Intro)
-, m_particleFactory(new ParticleFactory)
-, m_fadeAnimation(new FadeAnimation)
+  : m_game(game)
+  , m_stateMachine(stateMachine)
+  , m_renderer(renderer)
+  , m_messageOverlay(new MessageOverlay)
+  , m_race(std::make_shared<Race>(game, carCount()))
+  , m_activeTrack(nullptr)
+  , m_world(world)
+  , m_startlights(new Startlights)
+  , m_startlightsOverlay(new StartlightsOverlay(*m_startlights))
+  , m_checkeredFlag(new CheckeredFlag)
+  , m_intro(new Intro)
+  , m_particleFactory(new ParticleFactory)
+  , m_fadeAnimation(new FadeAnimation)
 {
-    connect(m_startlights, SIGNAL(raceStarted()), &m_race, SLOT(start()));
-    connect(m_startlights, SIGNAL(animationEnded()), &m_stateMachine, SLOT(endStartlightAnimation()));
+    initializeComponents();
 
-    connect(&m_stateMachine, SIGNAL(startlightAnimationRequested()), m_startlights, SLOT(beginAnimation()));
-    connect(&m_stateMachine, SIGNAL(fadeInRequested(int, int, int)), m_fadeAnimation, SLOT(beginFadeIn(int, int, int)));
-    connect(&m_stateMachine, SIGNAL(fadeOutRequested(int, int, int)), m_fadeAnimation, SLOT(beginFadeOut(int, int, int)));
-    connect(&m_stateMachine, SIGNAL(fadeOutFlashRequested(int, int, int)), m_fadeAnimation, SLOT(beginFadeOutFlash(int, int, int)));
-    connect(&m_stateMachine, SIGNAL(soundsStopped()), &m_race, SLOT(stopEngineSounds()));
+    connectComponents();
 
-    connect(m_fadeAnimation, SIGNAL(fadeValueChanged(float)), &m_renderer, SLOT(setFadeValue(float)));
-    connect(m_fadeAnimation, SIGNAL(fadeInFinished()), &m_stateMachine, SLOT(endFadeIn()));
-    connect(m_fadeAnimation, SIGNAL(fadeOutFinished()), &m_stateMachine, SLOT(endFadeOut()));
+    createMenus();
+}
 
-    connect(&m_race, SIGNAL(finished()), &m_stateMachine, SLOT(finishRace()));
-    connect(&m_race, SIGNAL(messageRequested(QString)), m_messageOverlay, SLOT(addMessage(QString)));
+void Scene::connectComponents()
+{
+    connect(m_startlights.get(), &Startlights::raceStarted, m_race.get(), &Race::start);
+    connect(m_startlights.get(), &Startlights::animationEnded, &m_stateMachine, &StateMachine::endStartlightAnimation);
 
-    connect(m_startlights, SIGNAL(messageRequested(QString)), m_messageOverlay, SLOT(addMessage(QString)));
-    connect(this, SIGNAL(listenerLocationChanged(float, float)), &m_game.audioWorker(), SLOT(setListenerLocation(float, float)));
+    connect(&m_stateMachine, &StateMachine::startlightAnimationRequested, m_startlights.get(), &Startlights::beginAnimation);
+    connect(&m_stateMachine, &StateMachine::fadeInRequested, m_fadeAnimation.get(), &FadeAnimation::beginFadeIn);
+    connect(&m_stateMachine, &StateMachine::fadeOutRequested, m_fadeAnimation.get(), &FadeAnimation::beginFadeOut);
+    connect(&m_stateMachine, &StateMachine::fadeOutFlashRequested, m_fadeAnimation.get(), &FadeAnimation::beginFadeOutFlash);
+    connect(&m_stateMachine, &StateMachine::soundsStopped, m_race.get(), &Race::stopEngineSounds);
 
-    m_game.audioWorker().connectAudioSource(m_race);
+    connect(m_fadeAnimation.get(), &FadeAnimation::fadeValueChanged, &m_renderer, &Renderer::setFadeValue);
+    connect(m_fadeAnimation.get(), &FadeAnimation::fadeInFinished, &m_stateMachine, &StateMachine::endFadeIn);
+    connect(m_fadeAnimation.get(), &FadeAnimation::fadeOutFinished, &m_stateMachine, &StateMachine::endFadeOut);
 
-    for (int i = 0; i < 2; i++)
+    connect(m_race.get(), &Race::finished, &m_stateMachine, &StateMachine::finishRace);
+    connect(m_race.get(), &Race::messageRequested, m_messageOverlay.get(), static_cast<void (MessageOverlay::*)(QString)>(&MessageOverlay::addMessage));
+
+    connect(m_startlights.get(), &Startlights::messageRequested, m_messageOverlay.get(), static_cast<void (MessageOverlay::*)(QString)>(&MessageOverlay::addMessage));
+    connect(this, &Scene::listenerLocationChanged, &m_game.audioWorker(), &AudioWorker::setListenerLocation);
+
+    m_game.audioWorker().connectAudioSource(*m_race);
+}
+
+void Scene::initializeComponents()
+{
+    for (size_t i = 0; i < 2; i++)
     {
-        m_cameraOffset[i] = 0.0f;
-        m_timingOverlay[i].setRace(m_race);
+        m_cameraOffset.at(i) = 0.0f;
+        m_timingOverlay.at(i).setRace(m_race);
     }
 
     m_checkeredFlag->setDimensions(width(), height());
@@ -133,61 +142,55 @@ Scene::Scene(Game & game, StateMachine & stateMachine, Renderer & renderer, MCWo
 
     m_world.setMetersPerUnit(METERS_PER_UNIT);
 
-    MCAssetManager::textureFontManager().font(m_game.fontName()).setShaderProgram(
-        m_renderer.program("text"));
-    MCAssetManager::textureFontManager().font(m_game.fontName()).setShadowShaderProgram(
-        m_renderer.program("textShadow"));
+    MCAssetManager::textureFontManager().font(m_game.fontName()).setShaderProgram(m_renderer.program("text"));
+    MCAssetManager::textureFontManager().font(m_game.fontName()).setShadowShaderProgram(m_renderer.program("textShadow"));
 
-    const MCGLAmbientLight ambientLight(1.0, 0.9, 0.95, 0.75);
-    const MCGLDiffuseLight diffuseLight(MCVector3dF(1.0, -1.0, -1.0), 1.0, 0.9, 0.5, 0.75);
-    const MCGLDiffuseLight specularLight(MCVector3dF(1.0, -1.0, -1.0), 1.0, 1.0, 0.8, 0.9);
+    const MCGLAmbientLight ambientLight(1.0f, 0.9f, 0.95f, 0.75f);
+    const MCGLDiffuseLight diffuseLight(MCVector3dF(1.0f, -1.0f, -1.0f), 1.0f, 0.9f, 0.5f, 0.75f);
+    const MCGLDiffuseLight specularLight(MCVector3dF(1.0f, -1.0f, -1.0f), 1.0f, 1.0f, 0.8f, 0.9f);
 
-    MCGLScene & glScene = MCWorld::instance().renderer().glScene();
+    auto & glScene = MCWorld::instance().renderer().glScene();
     glScene.setAmbientLight(ambientLight);
     glScene.setDiffuseLight(diffuseLight);
     glScene.setSpecularLight(specularLight);
 
     m_renderer.setFadeValue(0.0);
-
-    createMenus();
 }
 
-void Scene::setupAudio(Car & car, int index)
+void Scene::setupAudio(Car & car, size_t index)
 {
-    std::stringstream engine;
-    engine << "carEngine" << index;
-
-    std::stringstream hit;
-    hit << "carHit" << index;
-
-    std::stringstream skid;
-    skid << "skid" << index;
-
     CarSoundEffectManager::MultiSoundHandles handles;
-    handles.engineSoundHandle = engine.str().c_str();
-    handles.hitSoundHandle    = hit.str().c_str();
-    handles.skidSoundHandle   = skid.str().c_str();
 
-    CarSoundEffectManagerPtr sfx(new CarSoundEffectManager(car, handles));
+    const auto indexStr = std::to_string(index);
+    const auto engine = "carEngine" + indexStr;
+    handles.engineSoundHandle = engine.c_str();
+
+    const auto hit = "carHit" + indexStr;
+    handles.hitSoundHandle = hit.c_str();
+
+    const auto skid = "skid" + indexStr;
+    handles.skidSoundHandle = skid.c_str();
+
+    const auto sfx = std::make_shared<CarSoundEffectManager>(car, handles);
     m_game.audioWorker().connectAudioSource(*sfx);
     car.setSoundEffectManager(sfx);
 }
 
 void Scene::createCars()
 {
-    m_race.removeCars();
+    m_race->removeCars();
     m_cars.clear();
     m_ai.clear();
 
     // Create and add cars.
-    for (int i = 0; i < NUM_CARS; i++)
+    for (size_t i = 0; i < carCount(); i++)
     {
-        CarPtr car(CarFactory::buildCar(i, NUM_CARS, m_game));
+        CarPtr car(CarFactory::buildCar(i, carCount(), m_game));
         if (car)
         {
             if (!car->isHuman())
             {
-                m_ai.push_back(AIPtr(new AI(*car)));
+                m_ai.push_back(std::make_shared<AI>(*car, m_race));
             }
 
             car->shape()->view()->setShaderProgram(m_renderer.program("car"));
@@ -196,29 +199,28 @@ void Scene::createCars()
             setupAudio(*car, i);
 
             m_cars.push_back(car);
-            m_race.addCar(*car);
+            m_race->addCar(*car);
         }
     }
 
     if (m_game.hasTwoHumanPlayers())
     {
-        m_timingOverlay[1].setCarToFollow(*m_cars.at(1));
-        m_crashOverlay[1].setCarToFollow(*m_cars.at(1));
+        m_timingOverlay.at(1).setCarToFollow(*m_cars.at(1));
+        m_crashOverlay.at(1).setCarToFollow(*m_cars.at(1));
     }
 
-    m_timingOverlay[0].setCarToFollow(*m_cars.at(0));
-    m_crashOverlay[0].setCarToFollow(*m_cars.at(0));
+    m_timingOverlay.at(0).setCarToFollow(*m_cars.at(0));
+    m_crashOverlay.at(0).setCarToFollow(*m_cars.at(0));
 }
 
 void Scene::setupMinimaps()
 {
-    const int minimapSize = m_width * 0.2f;
+    const auto minimapSize = static_cast<int>(m_width * 0.2f);
+    const auto minimapY = !m_game.hasTwoHumanPlayers() ? minimapSize : minimapSize / 2 + 10;
 
-    const int minimapY = !m_game.hasTwoHumanPlayers() ? minimapSize : minimapSize / 2 + 10;
-
-    for (int i = 0; i < 2; i++)
+    for (size_t i = 0; i < 2; i++)
     {
-        m_minimap[i].initialize(*m_cars[i], m_activeTrack->trackData().map(), minimapSize / 2 + 10, minimapY, minimapSize);
+        m_minimap.at(i).initialize(*m_cars.at(i), m_activeTrack->trackData().map(), minimapSize / 2 + 10, minimapY, minimapSize);
     }
 }
 
@@ -234,17 +236,22 @@ int Scene::height()
 
 void Scene::setSize(int width, int height)
 {
-    Scene::m_width  = width;
+    Scene::m_width = width;
     Scene::m_height = height;
 }
 
+size_t Scene::carCount()
+{
+    return 12;
+}
+
 void Scene::createMenus()
 {
-    m_menuManager = new MTFH::MenuManager;
+    m_menuManager.reset(new MTFH::MenuManager);
 
-    m_mainMenu = MTFH::MenuPtr(new MainMenu(*m_menuManager, *this, width(), height()));
+    m_mainMenu = std::make_shared<MainMenu>(*m_menuManager, *this, width(), height());
     connect(
-        std::static_pointer_cast<MainMenu>(m_mainMenu).get(), SIGNAL(exitGameRequested()), &m_game, SLOT(exitGame()));
+      std::static_pointer_cast<MainMenu>(m_mainMenu).get(), &MainMenu::exitGameRequested, &m_game, &Game::exitGame);
 
     m_menuManager->addMenu(m_mainMenu);
     m_menuManager->enterMenu(m_mainMenu);
@@ -252,14 +259,11 @@ void Scene::createMenus()
 
 void Scene::updateFrame(InputHandler & handler, int step)
 {
-    if (m_stateMachine.state() == StateMachine::State::GameTransitionIn  ||
-        m_stateMachine.state() == StateMachine::State::GameTransitionOut ||
-        m_stateMachine.state() == StateMachine::State::DoStartlights     ||
-        m_stateMachine.state() == StateMachine::State::Play)
+    if (m_stateMachine.state() == StateMachine::State::GameTransitionIn || m_stateMachine.state() == StateMachine::State::GameTransitionOut || m_stateMachine.state() == StateMachine::State::DoStartlights || m_stateMachine.state() == StateMachine::State::Play)
     {
         if (m_activeTrack)
         {
-            if (m_race.started())
+            if (m_race->started())
             {
                 processUserInput(handler);
                 updateAi();
@@ -270,14 +274,14 @@ void Scene::updateFrame(InputHandler & handler, int step)
 
             if (m_game.hasTwoHumanPlayers())
             {
-                for (int i = 0; i < 2; i++)
+                for (size_t i = 0; i < 2; i++)
                 {
-                    updateCameraLocation(m_camera[i], m_cameraOffset[i], *m_cars.at(i));
+                    updateCameraLocation(m_camera.at(i), m_cameraOffset.at(i), *m_cars.at(i));
                 }
             }
             else
             {
-                updateCameraLocation(m_camera[0], m_cameraOffset[0], *m_cars.at(0));
+                updateCameraLocation(m_camera.at(0), m_cameraOffset.at(0), *m_cars.at(0));
             }
         }
     }
@@ -286,11 +290,10 @@ void Scene::updateFrame(InputHandler & handler, int step)
         m_menuManager->stepTime(step);
     }
 
-    const float fadeValue = m_renderer.fadeValue();
     if (m_fadeAnimation->isFading())
     {
-        MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-        glScene.setFadeValue(fadeValue);
+        auto & glScene = MCWorld::instance().renderer().glScene();
+        glScene.setFadeValue(m_renderer.fadeValue());
     }
 }
 
@@ -298,17 +301,17 @@ void Scene::updateOverlays()
 {
     if (m_game.hasTwoHumanPlayers())
     {
-        m_timingOverlay[1].update();
-        m_crashOverlay[1].update();
+        m_timingOverlay.at(1).update();
+        m_crashOverlay.at(1).update();
     }
 
-    m_timingOverlay[0].update();
-    m_crashOverlay[0].update();
+    m_timingOverlay.at(0).update();
+    m_crashOverlay.at(0).update();
 
     m_messageOverlay->update();
 }
 
-void Scene::updateWorld(float timeStep)
+void Scene::updateWorld(int timeStep)
 {
     // Step time
     m_world.stepTime(timeStep);
@@ -317,9 +320,9 @@ void Scene::updateWorld(float timeStep)
 void Scene::updateRace()
 {
     // Update race situation
-    m_race.update();
+    m_race->update();
 
-    emit listenerLocationChanged(m_cars[0]->location().i(), m_cars[0]->location().j());
+    emit listenerLocationChanged(m_cars.at(0)->location().i(), m_cars.at(0)->location().j());
 }
 
 void Scene::updateCameraLocation(MCCamera & camera, float & offset, MCObject & object)
@@ -327,38 +330,40 @@ void Scene::updateCameraLocation(MCCamera & camera, float & offset, MCObject & o
     // Update camera location with respect to the car speed.
     // Make changes a bit smoother so that an abrupt decrease
     // in the speed won't look bad.
-    MCVector2dF loc(object.location());
-
-    const float offsetAmplification = m_game.hasTwoHumanPlayers() ? 9.6 : 13.8;
-    const float smooth              = 0.2;
-
-    offset += (object.physicsComponent().velocity().lengthFast() - offset) * smooth;
-    loc    += object.direction() * offset * offsetAmplification;
-
+    offset += (object.physicsComponent().velocity().lengthFast() - offset) * 0.2f;
+    const float offsetAmplification = m_game.hasTwoHumanPlayers() ? 9.6f : 13.8f;
+    const auto loc = MCVector2dF(object.location()) + object.direction() * offset * offsetAmplification;
     camera.setPos(loc.i(), loc.j());
 }
 
 void Scene::processUserInput(InputHandler & handler)
 {
-    for (int i = 0; i < (m_game.hasTwoHumanPlayers() ? 2 : 1); i++)
+    for (size_t i = 0; i < (m_game.hasTwoHumanPlayers() ? 2 : 1); i++)
     {
-        m_cars.at(i)->clearStatuses();
-
         // Handle accelerating / braking
         if (handler.getActionState(i, InputHandler::Action::Down))
         {
-            if (!m_race.timing().raceCompleted(i))
+            if (!m_race->timing().raceCompleted(i))
             {
-                m_cars.at(i)->brake();
+                m_cars.at(i)->setBrakeEnabled(true);
             }
         }
-        else if (handler.getActionState(i, InputHandler::Action::Up))
+        else
         {
-            if (!m_race.timing().raceCompleted(i))
+            m_cars.at(i)->setBrakeEnabled(false);
+        }
+
+        if (handler.getActionState(i, InputHandler::Action::Up))
+        {
+            if (!m_race->timing().raceCompleted(i))
             {
-                m_cars.at(i)->accelerate();
+                m_cars.at(i)->setAcceleratorEnabled(true);
             }
         }
+        else
+        {
+            m_cars.at(i)->setAcceleratorEnabled(false);
+        }
 
         // Handle turning
         if (handler.getActionState(i, InputHandler::Action::Left))
@@ -378,9 +383,9 @@ void Scene::processUserInput(InputHandler & handler)
 
 void Scene::updateAi()
 {
-    for (AIPtr ai : m_ai)
+    for (auto && ai : m_ai)
     {
-        const bool isRaceCompleted = m_race.timing().raceCompleted(ai->car().index());
+        const bool isRaceCompleted = m_race->timing().raceCompleted(ai->car().index());
         ai->update(isRaceCompleted);
     }
 }
@@ -390,46 +395,46 @@ void Scene::setupCameras(Track & activeTrack)
     m_world.renderer().removeParticleVisibilityCameras();
     if (m_game.hasTwoHumanPlayers())
     {
-        for (int i = 0; i < 2; i++)
+        for (size_t i = 0; i < 2; i++)
         {
             if (m_game.splitType() == Game::SplitType::Vertical)
             {
-                m_camera[i].init(
-                    Scene::width() / 2, Scene::height(), 0, 0, activeTrack.width(), activeTrack.height());
-                m_world.renderer().addParticleVisibilityCamera(m_camera[i]);
+                m_camera.at(i).init(
+                  Scene::width() / 2, Scene::height(), 0, 0, activeTrack.width(), activeTrack.height());
+                m_world.renderer().addParticleVisibilityCamera(m_camera.at(i));
             }
             else
             {
-                m_camera[i].init(
-                    Scene::width(), Scene::height() / 2, 0, 0, activeTrack.width(), activeTrack.height());
-                m_world.renderer().addParticleVisibilityCamera(m_camera[i]);
+                m_camera.at(i).init(
+                  Scene::width(), Scene::height() / 2, 0, 0, activeTrack.width(), activeTrack.height());
+                m_world.renderer().addParticleVisibilityCamera(m_camera.at(i));
             }
         }
     }
     else
     {
-        m_camera[0].init(
-            Scene::width(), Scene::height(), 0, 0, activeTrack.width(), activeTrack.height());
-        m_world.renderer().addParticleVisibilityCamera(m_camera[0]);
+        m_camera.at(0).init(
+          Scene::width(), Scene::height(), 0, 0, activeTrack.width(), activeTrack.height());
+        m_world.renderer().addParticleVisibilityCamera(m_camera.at(0));
     }
 }
 
-void Scene::setupAI(Track & activeTrack)
+void Scene::setupAI(std::shared_ptr<Track> activeTrack)
 {
-    for (AIPtr ai : m_ai)
+    for (auto && ai : m_ai)
     {
         ai->setTrack(activeTrack);
     }
 }
 
-void Scene::setActiveTrack(Track & activeTrack)
+void Scene::setActiveTrack(std::shared_ptr<Track> activeTrack)
 {
-    m_activeTrack = &activeTrack;
+    m_activeTrack = activeTrack;
 
     // Remove previous objects
     m_world.clear();
 
-    setupCameras(activeTrack);
+    setupCameras(*activeTrack);
 
     setWorldDimensions();
 
@@ -441,7 +446,7 @@ void Scene::setActiveTrack(Track & activeTrack)
 
     addTrackObjectsToWorld();
 
-    initRace();
+    initializeRace();
 
     setupAI(activeTrack);
 
@@ -454,12 +459,12 @@ void Scene::setWorldDimensions()
 
     // Update world dimensions according to the
     // active track.
-    const unsigned int minX = 0;
-    const unsigned int maxX = m_activeTrack->width();
-    const unsigned int minY = 0;
-    const unsigned int maxY = m_activeTrack->height();
-    const unsigned int minZ = 0;
-    const unsigned int maxZ = 1000;
+    const size_t minX = 0;
+    const size_t maxX = m_activeTrack->width();
+    const size_t minY = 0;
+    const size_t maxY = m_activeTrack->height();
+    const size_t minZ = 0;
+    const size_t maxZ = 1000;
 
     m_world.setDimensions(minX, maxX, minY, maxY, minZ, maxZ, METERS_PER_UNIT);
 }
@@ -467,7 +472,7 @@ void Scene::setWorldDimensions()
 void Scene::addCarsToWorld()
 {
     // Add objects to the world
-    for (CarPtr car : m_cars)
+    for (auto && car : m_cars)
     {
         car->addToWorld();
     }
@@ -484,9 +489,9 @@ void Scene::createNormalObjects()
 {
     assert(m_activeTrack);
 
-    for (unsigned int i = 0; i < m_activeTrack->trackData().objects().count(); i++)
+    for (size_t i = 0; i < m_activeTrack->trackData().objects().count(); i++)
     {
-        auto trackObject = dynamic_pointer_cast<TrackObject>(m_activeTrack->trackData().objects().object(i));
+        const auto trackObject = dynamic_pointer_cast<TrackObject>(m_activeTrack->trackData().objects().object(i));
         assert(trackObject);
 
         MCObject & object = trackObject->object();
@@ -496,7 +501,7 @@ void Scene::createNormalObjects()
         float baseZ = 0;
         if (object.shape() && object.shape()->view() && object.shape()->view()->object())
         {
-            if (dynamic_cast<MCMesh*>(object.shape()->view()->object()))
+            if (dynamic_cast<MCMesh *>(object.shape()->view()->object()))
             {
                 baseZ = -object.shape()->view()->object()->minZ();
             }
@@ -507,7 +512,8 @@ void Scene::createNormalObjects()
 
         if (auto pit = dynamic_cast<Pit *>(&object))
         {
-            connect(pit, SIGNAL(pitStop(Car &)), &m_race, SLOT(pitStop(Car &)));
+            pit->reset();
+            connect(pit, &Pit::pitStop, m_race.get(), &Race::pitStop);
         }
     }
 }
@@ -516,27 +522,24 @@ void Scene::createBridgeObjects()
 {
     assert(m_activeTrack);
 
-    const MapBase & rMap = m_activeTrack->trackData().map();
-
-    static const int w = TrackTile::TILE_W;
-    static const int h = TrackTile::TILE_H;
-
-    for (unsigned int j = 0; j <= rMap.rows(); j++)
+    const auto & map = m_activeTrack->trackData().map();
+    for (size_t j = 0; j <= map.rows(); j++)
     {
-        for (unsigned int i = 0; i <= rMap.cols(); i++)
+        for (size_t i = 0; i <= map.cols(); i++)
         {
-            auto tile = dynamic_pointer_cast<TrackTile>(rMap.getTile(i, j));
-            if (tile && tile->tileTypeEnum() == TrackTile::TT_BRIDGE)
+            auto tile = dynamic_pointer_cast<TrackTile>(map.getTile(i, j));
+            if (tile && tile->tileTypeEnum() == TrackTile::TileType::Bridge)
             {
-                MCObjectPtr bridge(new Bridge);
-
-                bridge->translate(MCVector3dF(i * w + w / 2, j * h + h / 2, 0));
+                const auto bridge = std::make_shared<Bridge>();
+                bridge->translate(MCVector3dF(i * TrackTile::width() + TrackTile::width() / 2, j * TrackTile::height() + TrackTile::height() / 2, 0));
                 bridge->rotate(tile->rotation());
                 bridge->addToWorld();
                 m_bridges.push_back(bridge);
             }
         }
     }
+
+    Bridge::reset();
 }
 
 void Scene::resizeOverlays()
@@ -545,38 +548,37 @@ void Scene::resizeOverlays()
     {
         if (m_game.splitType() == Game::SplitType::Vertical)
         {
-            for (int i = 0; i < 2; i++)
+            for (size_t i = 0; i < 2; i++)
             {
-                m_timingOverlay[i].setDimensions(width() / 2, height());
-                m_crashOverlay[i].setDimensions(width() / 2, height());
+                m_timingOverlay.at(i).setDimensions(width() / 2, height());
+                m_crashOverlay.at(i).setDimensions(width() / 2, height());
             }
         }
         else
         {
-            for (int i = 0; i < 2; i++)
+            for (size_t i = 0; i < 2; i++)
             {
-                m_timingOverlay[i].setDimensions(width(), height() / 2);
-                m_crashOverlay[i].setDimensions(width(), height() / 2);
+                m_timingOverlay.at(i).setDimensions(width(), height() / 2);
+                m_crashOverlay.at(i).setDimensions(width(), height() / 2);
             }
         }
     }
     else
     {
-        m_timingOverlay[0].setDimensions(width(), height());
-        m_crashOverlay[0].setDimensions(width(), height());
+        m_timingOverlay.at(0).setDimensions(width(), height());
+        m_crashOverlay.at(0).setDimensions(width(), height());
     }
 }
 
-void Scene::initRace()
+void Scene::initializeRace()
 {
     assert(m_activeTrack);
-    m_race.init(*m_activeTrack, m_game.lapCount());
+    m_race->init(m_activeTrack, static_cast<size_t>(m_game.lapCount()));
 }
 
-Track & Scene::activeTrack() const
+std::shared_ptr<Track> Scene::activeTrack() const
 {
-    assert(m_activeTrack);
-    return *m_activeTrack;
+    return m_activeTrack;
 }
 
 MTFH::MenuPtr Scene::trackSelectionMenu() const
@@ -607,42 +609,40 @@ void Scene::renderTrack()
     case StateMachine::State::DoStartlights:
     case StateMachine::State::Play:
     {
-        MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-
         if (m_game.hasTwoHumanPlayers())
         {
             MCGLScene::SplitType p1, p0;
             getSplitPositions(p1, p0);
 
+            auto & glScene = MCWorld::instance().renderer().glScene();
+
             glScene.setSplitType(p1);
-            m_activeTrack->render(&m_camera[1]);
+            m_activeTrack->render(m_camera.at(1));
 
             glScene.setSplitType(p0);
-            m_activeTrack->render(&m_camera[0]);
+            m_activeTrack->render(m_camera.at(0));
 
             glScene.setSplitType(MCGLScene::ShowFullScreen);
         }
         else
         {
-            m_activeTrack->render(&m_camera[0]);
+            m_activeTrack->render(m_camera.at(0));
         }
 
         break;
     }
     default:
         break;
-    };
+    }
 }
 
 void Scene::renderMenu()
 {
-    MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-
     switch (m_stateMachine.state())
     {
     case StateMachine::State::DoIntro:
 
-        glScene.setSplitType(MCGLScene::ShowFullScreen);
+        MCWorld::instance().renderer().glScene().setSplitType(MCGLScene::ShowFullScreen);
 
         m_intro->render();
 
@@ -652,7 +652,7 @@ void Scene::renderMenu()
     case StateMachine::State::MenuTransitionOut:
     case StateMachine::State::MenuTransitionIn:
 
-        glScene.setSplitType(MCGLScene::ShowFullScreen);
+        MCWorld::instance().renderer().glScene().setSplitType(MCGLScene::ShowFullScreen);
 
         m_menuManager->render();
 
@@ -660,7 +660,7 @@ void Scene::renderMenu()
 
     default:
         break;
-    };
+    }
 }
 
 void Scene::renderCommonHUD()
@@ -673,10 +673,9 @@ void Scene::renderCommonHUD()
     case StateMachine::State::Play:
     {
         // Setup for common scene
-        MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-        glScene.setSplitType(MCGLScene::ShowFullScreen);
+        MCWorld::instance().renderer().glScene().setSplitType(MCGLScene::ShowFullScreen);
 
-        if (m_race.checkeredFlagEnabled() && !m_game.hasTwoHumanPlayers())
+        if (m_race->checkeredFlagEnabled() && !m_game.hasTwoHumanPlayers())
         {
             m_checkeredFlag->render();
         }
@@ -687,7 +686,7 @@ void Scene::renderCommonHUD()
     }
     default:
         break;
-    };
+    }
 }
 
 void Scene::renderHUD()
@@ -699,37 +698,37 @@ void Scene::renderHUD()
     case StateMachine::State::DoStartlights:
     case StateMachine::State::Play:
     {
-        MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-
         if (m_game.hasTwoHumanPlayers())
         {
             MCGLScene::SplitType p1, p0;
             getSplitPositions(p1, p0);
 
+            auto & glScene = MCWorld::instance().renderer().glScene();
+
             glScene.setSplitType(p1);
-            m_timingOverlay[1].render();
-            m_minimap[1].render(m_cars, m_race);
-            m_crashOverlay[1].render();
+            m_timingOverlay.at(1).render();
+            m_minimap.at(1).render(m_cars, *m_race);
+            m_crashOverlay.at(1).render();
 
             glScene.setSplitType(p0);
-            m_timingOverlay[0].render();
-            m_minimap[0].render(m_cars, m_race);
-            m_crashOverlay[0].render();
+            m_timingOverlay.at(0).render();
+            m_minimap.at(0).render(m_cars, *m_race);
+            m_crashOverlay.at(0).render();
 
             glScene.setSplitType(MCGLScene::ShowFullScreen);
         }
         else
         {
-            m_timingOverlay[0].render();
-            m_minimap[0].render(m_cars, m_race);
-            m_crashOverlay[0].render();
+            m_timingOverlay.at(0).render();
+            m_minimap.at(0).render(m_cars, *m_race);
+            m_crashOverlay.at(0).render();
         }
 
         break;
     }
     default:
         break;
-    };
+    }
 }
 
 void Scene::renderWorld(MCRenderGroup renderGroup, bool prepareRendering)
@@ -741,8 +740,6 @@ void Scene::renderWorld(MCRenderGroup renderGroup, bool prepareRendering)
     case StateMachine::State::DoStartlights:
     case StateMachine::State::Play:
     {
-        MCGLScene & glScene = MCWorld::instance().renderer().glScene();
-
         if (m_game.hasTwoHumanPlayers())
         {
             MCGLScene::SplitType p1, p0;
@@ -750,15 +747,17 @@ void Scene::renderWorld(MCRenderGroup renderGroup, bool prepareRendering)
 
             if (prepareRendering)
             {
-                m_world.prepareRendering(&m_camera[1]);
-                m_world.prepareRendering(&m_camera[0]);
+                m_world.prepareRendering(&m_camera.at(1));
+                m_world.prepareRendering(&m_camera.at(0));
             }
 
+            auto & glScene = MCWorld::instance().renderer().glScene();
+
             glScene.setSplitType(p1);
-            m_world.render(&m_camera[1], renderGroup);
+            m_world.render(&m_camera.at(1), renderGroup);
 
             glScene.setSplitType(p0);
-            m_world.render(&m_camera[0], renderGroup);
+            m_world.render(&m_camera.at(0), renderGroup);
 
             glScene.setSplitType(MCGLScene::ShowFullScreen);
         }
@@ -766,26 +765,17 @@ void Scene::renderWorld(MCRenderGroup renderGroup, bool prepareRendering)
         {
             if (prepareRendering)
             {
-                m_world.prepareRendering(&m_camera[0]);
+                m_world.prepareRendering(&m_camera.at(0));
             }
 
-            m_world.render(&m_camera[0], renderGroup);
+            m_world.render(&m_camera.at(0), renderGroup);
         }
 
         break;
     }
     default:
         break;
-    };
+    }
 }
 
-Scene::~Scene()
-{
-    delete m_fadeAnimation;
-    delete m_intro;
-    delete m_menuManager;
-    delete m_messageOverlay;
-    delete m_particleFactory;
-    delete m_startlights;
-    delete m_startlightsOverlay;
-}
+Scene::~Scene() = default;
