@@ -4,22 +4,22 @@
 <context>
     <name>MainMenu</name>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="56"/>
+        <location filename="../menu/mainmenu.cpp" line="57"/>
         <source>Play</source>
         <translation>Přehrát</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="60"/>
+        <location filename="../menu/mainmenu.cpp" line="61"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="64"/>
+        <location filename="../menu/mainmenu.cpp" line="65"/>
         <source>Credits</source>
         <translation>Zásluhy</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="68"/>
+        <location filename="../menu/mainmenu.cpp" line="69"/>
         <source>Quit</source>
         <translation>Ukončit</translation>
     </message>
@@ -48,52 +48,52 @@
         <translation type="vanished">Je vyžadováno alespoň OpenGL 2.1!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="318"/>
+        <location filename="../race.cpp" line="320"/>
         <source>The Time Trial has ended!</source>
         <translation>Časová zkouška!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="322"/>
+        <location filename="../race.cpp" line="324"/>
         <source>The winner has finished!</source>
         <translation>Vítěz dokončil!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="68"/>
+        <location filename="../race.cpp" line="69"/>
         <source>New lap record!</source>
         <translation>Nový rekord kola!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="74"/>
+        <location filename="../race.cpp" line="76"/>
         <source>New race record!</source>
         <translation>Nový rekord závodu!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="347"/>
+        <location filename="../race.cpp" line="349"/>
         <source>Pit stop!</source>
         <translation>Díra!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="517"/>
+        <location filename="../race.cpp" line="543"/>
         <source>A new best pos!</source>
         <translation>Nové nejlepší umístění!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="527"/>
+        <location filename="../race.cpp" line="553"/>
         <source>A new track unlocked!</source>
         <translation>Odemknuta nová trať!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="531"/>
+        <location filename="../race.cpp" line="557"/>
         <source>Better luck next time..</source>
         <translation>Příště víc štěstí..</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="574"/>
+        <location filename="../race.cpp" line="600"/>
         <source>You must stay on track!</source>
         <translation>Musíte zůstat na trati!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="578"/>
+        <location filename="../race.cpp" line="604"/>
         <source>Watch your tires!</source>
         <translation>Kontrolujte pláště!</translation>
     </message>
@@ -103,78 +103,79 @@
         <translation>Jeďte!</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="55"/>
+        <location filename="../timingoverlay.cpp" line="54"/>
         <source>---</source>
         <translation>---</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="56"/>
+        <location filename="../timingoverlay.cpp" line="55"/>
         <source>1st</source>
         <translation>1.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="57"/>
+        <location filename="../timingoverlay.cpp" line="56"/>
         <source>2nd</source>
         <translation>2.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="58"/>
+        <location filename="../timingoverlay.cpp" line="57"/>
         <source>3rd</source>
         <translation>3.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="59"/>
+        <location filename="../timingoverlay.cpp" line="58"/>
         <source>4th</source>
         <translation>4.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="60"/>
+        <location filename="../timingoverlay.cpp" line="59"/>
         <source>5th</source>
         <translation>5.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="61"/>
+        <location filename="../timingoverlay.cpp" line="60"/>
         <source>6th</source>
         <translation>6.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="62"/>
+        <location filename="../timingoverlay.cpp" line="61"/>
         <source>7th</source>
         <translation>7.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="63"/>
+        <location filename="../timingoverlay.cpp" line="62"/>
         <source>8th</source>
         <translation>8.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="64"/>
+        <location filename="../timingoverlay.cpp" line="63"/>
         <source>9th</source>
         <translation>9.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="65"/>
+        <location filename="../timingoverlay.cpp" line="64"/>
         <source>10th</source>
         <translation>10.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="66"/>
+        <location filename="../timingoverlay.cpp" line="65"/>
         <source>11th</source>
         <translation>11.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="67"/>
+        <location filename="../timingoverlay.cpp" line="66"/>
         <source>12th</source>
         <translation>12.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="189"/>
+        <location filename="../timingoverlay.cpp" line="188"/>
         <source> LAP:</source>
         <translation> KOLO:</translation>
     </message>
     <message>
         <location filename="../timingoverlay.cpp" line="205"/>
         <source> POS:</source>
+        <extracomment>Position/rank</extracomment>
         <translation> UMÍS:</translation>
     </message>
     <message>
@@ -198,18 +199,21 @@
         <translation>KOLO:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="308"/>
+        <location filename="../timingoverlay.cpp" line="309"/>
         <source>L:</source>
+        <extracomment>Last lap time</extracomment>
         <translation>K:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="327"/>
+        <location filename="../timingoverlay.cpp" line="329"/>
         <source>R:</source>
+        <extracomment>Lap record time</extracomment>
         <translation>R:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="347"/>
+        <location filename="../timingoverlay.cpp" line="350"/>
         <source>TOT:</source>
+        <extracomment>Total race time</extracomment>
         <translation>CELKEM:</translation>
     </message>
     <message>
@@ -322,17 +326,17 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
 * Tommi Martela</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="80"/>
+        <location filename="../menu/settingsmenu.cpp" line="78"/>
         <source>Reset best positions?</source>
         <translation>Vynulovat nejlepší umístění?</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="92"/>
+        <location filename="../menu/settingsmenu.cpp" line="89"/>
         <source>Reset record times?</source>
         <translation>Vynulovat rekordní časy?</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="105"/>
+        <location filename="../menu/settingsmenu.cpp" line="101"/>
         <source>Reset unlocked tracks?</source>
         <translation>Vynulovat odemknuté tratě!</translation>
     </message>
@@ -341,22 +345,22 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="vanished">Obtížnost &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="208"/>
+        <location filename="../menu/settingsmenu.cpp" line="206"/>
         <source>Sounds &gt;</source>
         <translation>Zvuk &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="212"/>
+        <location filename="../menu/settingsmenu.cpp" line="210"/>
         <source>GFX &gt;</source>
         <translation>Obraz &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="216"/>
+        <location filename="../menu/settingsmenu.cpp" line="214"/>
         <source>Controls &gt;</source>
         <translation>Ovládání &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="220"/>
+        <location filename="../menu/settingsmenu.cpp" line="218"/>
         <source>Reset &gt;</source>
         <translation>Vynulování &gt;</translation>
     </message>
@@ -376,54 +380,54 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation>Těžký</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="346"/>
+        <location filename="../menu/settingsmenu.cpp" line="385"/>
         <source>VSync &gt;</source>
         <translation>Svislá synchronizace &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="365"/>
-        <location filename="../menu/vsyncmenu.cpp" line="103"/>
+        <location filename="../menu/settingsmenu.cpp" line="405"/>
+        <location filename="../menu/vsyncmenu.cpp" line="101"/>
         <source>Off</source>
         <translation>Vypnuto</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="378"/>
-        <location filename="../menu/vsyncmenu.cpp" line="107"/>
+        <location filename="../menu/settingsmenu.cpp" line="417"/>
+        <location filename="../menu/vsyncmenu.cpp" line="105"/>
         <source>On</source>
         <translation>Zapnuto</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="412"/>
+        <location filename="../menu/settingsmenu.cpp" line="450"/>
         <source>Reset record times</source>
         <translation>Vynulovat rekordní časy</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="417"/>
+        <location filename="../menu/settingsmenu.cpp" line="455"/>
         <source>Reset best positions</source>
         <translation>Vynulovat nejlepší umístění</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="422"/>
+        <location filename="../menu/settingsmenu.cpp" line="460"/>
         <source>Reset unlocked tracks</source>
         <translation>Vynulovat odemknuté tratě</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="334"/>
+        <location filename="../menu/settingsmenu.cpp" line="369"/>
         <source>Full screen resolution &gt;</source>
         <translation>Rozlišení v režimu na celou obrazovku &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="338"/>
+        <location filename="../menu/settingsmenu.cpp" line="373"/>
         <source>Windowed resolution &gt;</source>
         <translation>Rozlišení v okenním režimu &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="342"/>
+        <location filename="../menu/settingsmenu.cpp" line="381"/>
         <source>Split type &gt;</source>
         <translation>Typ rozdělení &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="204"/>
+        <location filename="../menu/settingsmenu.cpp" line="202"/>
         <source>Game mode &gt;</source>
         <translation>Herní režim &gt; </translation>
     </message>
@@ -432,50 +436,53 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="vanished">Počet kol &gt;</translation>
     </message>
     <message>
+        <location filename="../menu/settingsmenu.cpp" line="377"/>
         <source>FPS &gt;</source>
-        <translation type="obsolete">Snímků za sekundu &gt;</translation>
+        <translation type="unfinished">Snímků za sekundu &gt;</translation>
     </message>
     <message>
         <source>Key configuration &gt;</source>
         <translation type="obsolete">Nastavení kláves &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="242"/>
+        <location filename="../menu/settingsmenu.cpp" line="283"/>
         <source>Two player race</source>
         <translation>Závod se dvěma závodníky</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="252"/>
+        <location filename="../menu/settingsmenu.cpp" line="292"/>
         <source>One player race</source>
         <translation>Závod s jedním závodníkem</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="262"/>
+        <location filename="../menu/settingsmenu.cpp" line="301"/>
         <source>Time Trial</source>
         <translation>Časová zkouška</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="272"/>
+        <location filename="../menu/settingsmenu.cpp" line="310"/>
         <source>Duel</source>
         <translation>Duel</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="300"/>
+        <location filename="../menu/settingsmenu.cpp" line="337"/>
         <source>Vertical</source>
         <translation>Svislé</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="310"/>
+        <location filename="../menu/settingsmenu.cpp" line="346"/>
         <source>Horizontal</source>
         <translation>Vodorovné</translation>
     </message>
     <message>
+        <location filename="../menu/settingsmenu.cpp" line="241"/>
         <source>30 fps</source>
-        <translation type="obsolete">30 fps</translation>
+        <translation type="unfinished">30 fps</translation>
     </message>
     <message>
+        <location filename="../menu/settingsmenu.cpp" line="251"/>
         <source>60 fps</source>
-        <translation type="obsolete">60 fps</translation>
+        <translation type="unfinished">60 fps</translation>
     </message>
     <message>
         <source>  Laps: </source>
@@ -486,12 +493,12 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="obsolete">Délka: </translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="272"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="269"/>
         <source>       Laps: </source>
         <translation>       Kol: </translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="279"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="276"/>
         <source>     Length: </source>
         <translation>       Délka: </translation>
     </message>
@@ -500,12 +507,12 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="vanished"> m</translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="288"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="285"/>
         <source> Lap Record: </source>
         <translation> Rekord kola: </translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="294"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="291"/>
         <source>Race Record: </source>
         <translation>Rekord závodu: </translation>
     </message>
@@ -514,47 +521,47 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="obsolete">Rekord: </translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="52"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
         <source>Press a key..</source>
         <translation>Stiskněte klávesu...</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="92"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
         <source>Player One Accelerate</source>
         <translation>Závodník 1 zrychluje</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="102"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
         <source>Player One Brake</source>
         <translation>Závodník 1 brzdí</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="112"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
         <source>Player One Turn Left</source>
         <translation>Závodník 1 zahýbá doleva</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="122"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
         <source>Player One Turn Right</source>
         <translation>Závodník 1 zahýbá doprava</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="145"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
         <source>Player Two Accelerate</source>
         <translation>Závodník 2 zrychluje</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="155"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
         <source>Player Two Brake</source>
         <translation>Závodník 2 brzdí</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
         <source>Player Two Turn Left</source>
         <translation>Závodník 2 zahýbá doleva</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="175"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
         <source>Player Two Turn Right</source>
         <translation>Závodník 2 zahýbá doprava</translation>
     </message>
@@ -590,32 +597,32 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation>PROGRAMOVÁNÍ</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="44"/>
+        <location filename="../menu/credits.cpp" line="42"/>
         <source>GRAPHICS</source>
         <translation>OBRAZOVÁ STRÁNKA</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="49"/>
+        <location filename="../menu/credits.cpp" line="44"/>
         <source>LEVEL DESIGN</source>
         <translation>VNĚJŠÍ ÚPRAVA ÚROVNÍ</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="54"/>
+        <location filename="../menu/credits.cpp" line="46"/>
         <source>TRANSLATIONS</source>
         <translation>PŘEKLAD</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="62"/>
+        <location filename="../menu/credits.cpp" line="48"/>
         <source>PATCHES</source>
         <translation>ZÁPLATY</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="73"/>
+        <location filename="../menu/credits.cpp" line="50"/>
         <source>SPECIAL THANKS</source>
         <translation>ZVLÁŠTNÍ PODĚKOVÁNÍ</translation>
     </message>
     <message>
-        <location filename="../menu/resolutionmenu.cpp" line="117"/>
+        <location filename="../menu/resolutionmenu.cpp" line="115"/>
         <source>Restart to change the resolution.</source>
         <translation>Pro změnu rozlišení spusťte znovu.</translation>
     </message>
@@ -624,12 +631,12 @@ ZVLÁŠTNÍ PODĚKOVÁNÍ
         <translation type="vanished">Přirozené rozlišení</translation>
     </message>
     <message>
-        <location filename="../menu/vsyncmenu.cpp" line="78"/>
+        <location filename="../menu/vsyncmenu.cpp" line="77"/>
         <source>Restart to change VSync setting.</source>
         <translation>Pro změnu nastavení svislé synchronizace spusťte znovu.</translation>
     </message>
     <message>
-        <location filename="../menu/lapcountmenu.cpp" line="86"/>
+        <location filename="../menu/lapcountmenu.cpp" line="85"/>
         <source>Choose lap count</source>
         <translation>Vyberte počet kol</translation>
     </message>
