@@ -4,22 +4,22 @@
 <context>
     <name>MainMenu</name>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="56"/>
+        <location filename="../menu/mainmenu.cpp" line="57"/>
         <source>Play</source>
         <translation>Pelaa</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="60"/>
+        <location filename="../menu/mainmenu.cpp" line="61"/>
         <source>Help</source>
         <translation>Apua</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="64"/>
+        <location filename="../menu/mainmenu.cpp" line="65"/>
         <source>Credits</source>
         <translation>Tekijät</translation>
     </message>
     <message>
-        <location filename="../menu/mainmenu.cpp" line="68"/>
+        <location filename="../menu/mainmenu.cpp" line="69"/>
         <source>Quit</source>
         <translation>Poistu</translation>
     </message>
@@ -48,52 +48,52 @@
         <translation type="vanished">Vähintään OpenGL 2.1 vaaditaan!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="318"/>
+        <location filename="../race.cpp" line="320"/>
         <source>The Time Trial has ended!</source>
         <translation>Aika-ajo päättyi!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="322"/>
+        <location filename="../race.cpp" line="324"/>
         <source>The winner has finished!</source>
         <translation>Voittaja tuli maaliin!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="68"/>
+        <location filename="../race.cpp" line="69"/>
         <source>New lap record!</source>
         <translation>Uusi kierrosennätys!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="74"/>
+        <location filename="../race.cpp" line="76"/>
         <source>New race record!</source>
         <translation>Uusi kilpailuennätys!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="347"/>
+        <location filename="../race.cpp" line="349"/>
         <source>Pit stop!</source>
         <translation>Varikkopysähdys!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="517"/>
+        <location filename="../race.cpp" line="543"/>
         <source>A new best pos!</source>
         <translation>Uusi paras sijoitus!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="527"/>
+        <location filename="../race.cpp" line="553"/>
         <source>A new track unlocked!</source>
         <translation>Uusi rata avattu!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="531"/>
+        <location filename="../race.cpp" line="557"/>
         <source>Better luck next time..</source>
         <translation>Parempaa onnea ensi kerralla..</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="574"/>
+        <location filename="../race.cpp" line="600"/>
         <source>You must stay on track!</source>
         <translation>Pysy radalla!</translation>
     </message>
     <message>
-        <location filename="../race.cpp" line="578"/>
+        <location filename="../race.cpp" line="604"/>
         <source>Watch your tires!</source>
         <translation>Varo renkaitasi!</translation>
     </message>
@@ -103,78 +103,79 @@
         <translation>AJA!!!</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="55"/>
+        <location filename="../timingoverlay.cpp" line="54"/>
         <source>---</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="56"/>
+        <location filename="../timingoverlay.cpp" line="55"/>
         <source>1st</source>
         <translation>1.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="57"/>
+        <location filename="../timingoverlay.cpp" line="56"/>
         <source>2nd</source>
         <translation>2.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="58"/>
+        <location filename="../timingoverlay.cpp" line="57"/>
         <source>3rd</source>
         <translation>3.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="59"/>
+        <location filename="../timingoverlay.cpp" line="58"/>
         <source>4th</source>
         <translation>4.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="60"/>
+        <location filename="../timingoverlay.cpp" line="59"/>
         <source>5th</source>
         <translation>5.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="61"/>
+        <location filename="../timingoverlay.cpp" line="60"/>
         <source>6th</source>
         <translation>6.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="62"/>
+        <location filename="../timingoverlay.cpp" line="61"/>
         <source>7th</source>
         <translation>7.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="63"/>
+        <location filename="../timingoverlay.cpp" line="62"/>
         <source>8th</source>
         <translation>8.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="64"/>
+        <location filename="../timingoverlay.cpp" line="63"/>
         <source>9th</source>
         <translation>9.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="65"/>
+        <location filename="../timingoverlay.cpp" line="64"/>
         <source>10th</source>
         <translation>10.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="66"/>
+        <location filename="../timingoverlay.cpp" line="65"/>
         <source>11th</source>
         <translation>11.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="67"/>
+        <location filename="../timingoverlay.cpp" line="66"/>
         <source>12th</source>
         <translation>12.</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="189"/>
+        <location filename="../timingoverlay.cpp" line="188"/>
         <source> LAP:</source>
         <translation> KIER:</translation>
     </message>
     <message>
         <location filename="../timingoverlay.cpp" line="205"/>
         <source> POS:</source>
+        <extracomment>Position/rank</extracomment>
         <translation> SIJA:</translation>
     </message>
     <message>
@@ -198,18 +199,21 @@
         <translation>KIE:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="308"/>
+        <location filename="../timingoverlay.cpp" line="309"/>
         <source>L:</source>
+        <extracomment>Last lap time</extracomment>
         <translation>V:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="327"/>
+        <location filename="../timingoverlay.cpp" line="329"/>
         <source>R:</source>
+        <extracomment>Lap record time</extracomment>
         <translation>E:</translation>
     </message>
     <message>
-        <location filename="../timingoverlay.cpp" line="347"/>
+        <location filename="../timingoverlay.cpp" line="350"/>
         <source>TOT:</source>
+        <extracomment>Total race time</extracomment>
         <translation>KOK:</translation>
     </message>
     <message>
@@ -321,17 +325,17 @@ ERITYISKIITOKSET
 * Tommi Martela</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="80"/>
+        <location filename="../menu/settingsmenu.cpp" line="78"/>
         <source>Reset best positions?</source>
         <translation>Nollaa parhaat sijat?</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="92"/>
+        <location filename="../menu/settingsmenu.cpp" line="89"/>
         <source>Reset record times?</source>
         <translation>Nollaa ennätysajat?</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="105"/>
+        <location filename="../menu/settingsmenu.cpp" line="101"/>
         <source>Reset unlocked tracks?</source>
         <translation>Nollaa lukitsemattomat radat?</translation>
     </message>
@@ -340,17 +344,17 @@ ERITYISKIITOKSET
         <translation type="vanished">Vaikeustaso &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="208"/>
+        <location filename="../menu/settingsmenu.cpp" line="206"/>
         <source>Sounds &gt;</source>
         <translation>Äänet &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="212"/>
+        <location filename="../menu/settingsmenu.cpp" line="210"/>
         <source>GFX &gt;</source>
         <translation>Grafiikka &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="220"/>
+        <location filename="../menu/settingsmenu.cpp" line="218"/>
         <source>Reset &gt;</source>
         <translation>Nollaus &gt;</translation>
     </message>
@@ -370,42 +374,47 @@ ERITYISKIITOKSET
         <translation>Vaikea</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="346"/>
+        <location filename="../menu/settingsmenu.cpp" line="385"/>
         <source>VSync &gt;</source>
         <translation>VSync &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="412"/>
+        <location filename="../menu/settingsmenu.cpp" line="450"/>
         <source>Reset record times</source>
         <translation>Nollaa ennätysajat</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="417"/>
+        <location filename="../menu/settingsmenu.cpp" line="455"/>
         <source>Reset best positions</source>
         <translation>Nollaa parhaat sijat</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="422"/>
+        <location filename="../menu/settingsmenu.cpp" line="460"/>
         <source>Reset unlocked tracks</source>
         <translation>Nollaa lukitsemattomat radat</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="334"/>
+        <location filename="../menu/settingsmenu.cpp" line="369"/>
         <source>Full screen resolution &gt;</source>
         <translation>Koko näytön resoluutio &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="338"/>
+        <location filename="../menu/settingsmenu.cpp" line="373"/>
         <source>Windowed resolution &gt;</source>
         <translation>Ikkunoitu resoluutio &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="342"/>
+        <location filename="../menu/settingsmenu.cpp" line="377"/>
+        <source>FPS &gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../menu/settingsmenu.cpp" line="381"/>
         <source>Split type &gt;</source>
         <translation>Ruudunjaon tyyppi &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="204"/>
+        <location filename="../menu/settingsmenu.cpp" line="202"/>
         <source>Game mode &gt;</source>
         <translation>Pelimoodi &gt; </translation>
     </message>
@@ -414,47 +423,49 @@ ERITYISKIITOKSET
         <translation type="vanished">Kierrosmäärä &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="216"/>
+        <location filename="../menu/settingsmenu.cpp" line="214"/>
         <source>Controls &gt;</source>
         <translation>Kontrollit &gt;</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="242"/>
+        <location filename="../menu/settingsmenu.cpp" line="283"/>
         <source>Two player race</source>
         <translation>Kahden pelaajan kisa</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="252"/>
+        <location filename="../menu/settingsmenu.cpp" line="292"/>
         <source>One player race</source>
         <translation>Yhden pelaajan kisa</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="262"/>
+        <location filename="../menu/settingsmenu.cpp" line="301"/>
         <source>Time Trial</source>
         <translation>Aika-ajo</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="272"/>
+        <location filename="../menu/settingsmenu.cpp" line="310"/>
         <source>Duel</source>
         <translation>Kaksintaistelu</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="300"/>
+        <location filename="../menu/settingsmenu.cpp" line="337"/>
         <source>Vertical</source>
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="310"/>
+        <location filename="../menu/settingsmenu.cpp" line="346"/>
         <source>Horizontal</source>
         <translation>Vaaka</translation>
     </message>
     <message>
+        <location filename="../menu/settingsmenu.cpp" line="241"/>
         <source>30 fps</source>
-        <translation type="obsolete">30 ruutua/s</translation>
+        <translation type="unfinished">30 ruutua/s</translation>
     </message>
     <message>
+        <location filename="../menu/settingsmenu.cpp" line="251"/>
         <source>60 fps</source>
-        <translation type="obsolete">60 ruutua/s</translation>
+        <translation type="unfinished">60 ruutua/s</translation>
     </message>
     <message>
         <source>  Laps: </source>
@@ -465,12 +476,12 @@ ERITYISKIITOKSET
         <translation type="obsolete">       Pituus: </translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="272"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="269"/>
         <source>       Laps: </source>
         <translation>     Kierrokset:</translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="279"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="276"/>
         <source>     Length: </source>
         <translation>         Pituus:</translation>
     </message>
@@ -479,12 +490,12 @@ ERITYISKIITOKSET
         <translation type="vanished"> m</translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="288"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="285"/>
         <source> Lap Record: </source>
         <translation> Kierrosennätys:</translation>
     </message>
     <message>
-        <location filename="../menu/trackselectionmenu.cpp" line="294"/>
+        <location filename="../menu/trackselectionmenu.cpp" line="291"/>
         <source>Race Record: </source>
         <translation>Kilpailuennätys:</translation>
     </message>
@@ -493,47 +504,47 @@ ERITYISKIITOKSET
         <translation type="obsolete">      Ennätys: </translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="52"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
         <source>Press a key..</source>
         <translation>Paina näppäintä..</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="92"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
         <source>Player One Accelerate</source>
         <translation>Pelaaja 1 Kaasu</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="102"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
         <source>Player One Brake</source>
         <translation>Pelaaja 1 Jarru</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="112"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
         <source>Player One Turn Left</source>
         <translation>Pelaaja 1 Vasemmalle</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="122"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
         <source>Player One Turn Right</source>
         <translation>Pelaaja 1 Oikealle</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="145"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
         <source>Player Two Accelerate</source>
         <translation>Pelaaja 2 Kaasu</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="155"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
         <source>Player Two Brake</source>
         <translation>Pelaaja 2 Jarru</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
         <source>Player Two Turn Left</source>
         <translation>Pelaaja 2 Vasemmalle</translation>
     </message>
     <message>
-        <location filename="../menu/keyconfigmenu.cpp" line="175"/>
+        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
         <source>Player Two Turn Right</source>
         <translation>Pelaaja 2 Oikealle</translation>
     </message>
@@ -599,32 +610,32 @@ ERITYISKIITOKSET
         <translation>OHJELMOINTI</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="44"/>
+        <location filename="../menu/credits.cpp" line="42"/>
         <source>GRAPHICS</source>
         <translation>GRAFIIKKA</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="49"/>
+        <location filename="../menu/credits.cpp" line="44"/>
         <source>LEVEL DESIGN</source>
         <translation>RADAT</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="54"/>
+        <location filename="../menu/credits.cpp" line="46"/>
         <source>TRANSLATIONS</source>
         <translation>KÄÄNNÖKSET</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="62"/>
+        <location filename="../menu/credits.cpp" line="48"/>
         <source>PATCHES</source>
         <translation>PÄTSIT</translation>
     </message>
     <message>
-        <location filename="../menu/credits.cpp" line="73"/>
+        <location filename="../menu/credits.cpp" line="50"/>
         <source>SPECIAL THANKS</source>
         <translation>ERITYISKIITOKSET</translation>
     </message>
     <message>
-        <location filename="../menu/resolutionmenu.cpp" line="117"/>
+        <location filename="../menu/resolutionmenu.cpp" line="115"/>
         <source>Restart to change the resolution.</source>
         <translation>Uudelleenkäynnistys vaaditaan.</translation>
     </message>
@@ -643,24 +654,24 @@ ERITYISKIITOKSET
         <translation>Kumoa</translation>
     </message>
     <message>
-        <location filename="../menu/vsyncmenu.cpp" line="78"/>
+        <location filename="../menu/vsyncmenu.cpp" line="77"/>
         <source>Restart to change VSync setting.</source>
         <translation>Uudelleenkäynnistys vaaditaan.</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="365"/>
-        <location filename="../menu/vsyncmenu.cpp" line="103"/>
+        <location filename="../menu/settingsmenu.cpp" line="405"/>
+        <location filename="../menu/vsyncmenu.cpp" line="101"/>
         <source>Off</source>
         <translation>Pois</translation>
     </message>
     <message>
-        <location filename="../menu/settingsmenu.cpp" line="378"/>
-        <location filename="../menu/vsyncmenu.cpp" line="107"/>
+        <location filename="../menu/settingsmenu.cpp" line="417"/>
+        <location filename="../menu/vsyncmenu.cpp" line="105"/>
         <source>On</source>
         <translation>Päälle</translation>
     </message>
     <message>
-        <location filename="../menu/lapcountmenu.cpp" line="86"/>
+        <location filename="../menu/lapcountmenu.cpp" line="85"/>
         <source>Choose lap count</source>
         <translation>Valitse kierrosmäärä</translation>
     </message>
